Class: Google::Apis::RedisV1beta1::AutomatedBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

The automated backup config for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomatedBackupConfig

Returns a new instance of AutomatedBackupConfig.



360
361
362
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_modeString

Optional. The automated backup mode. If the mode is disabled, the other fields will be ignored. Corresponds to the JSON property automatedBackupMode

Returns:

  • (String)


345
346
347
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 345

def automated_backup_mode
  @automated_backup_mode
end

#fixed_frequency_scheduleGoogle::Apis::RedisV1beta1::FixedFrequencySchedule

This schedule allows the backup to be triggered at a fixed frequency ( currently only daily is supported). Corresponds to the JSON property fixedFrequencySchedule



351
352
353
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 351

def fixed_frequency_schedule
  @fixed_frequency_schedule
end

#retentionString

Optional. How long to keep automated backups before the backups are deleted. The value should be between 1 day and 365 days. If not specified, the default value is 35 days. Corresponds to the JSON property retention

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 358

def retention
  @retention
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



365
366
367
368
369
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 365

def update!(**args)
  @automated_backup_mode = args[:automated_backup_mode] if args.key?(:automated_backup_mode)
  @fixed_frequency_schedule = args[:fixed_frequency_schedule] if args.key?(:fixed_frequency_schedule)
  @retention = args[:retention] if args.key?(:retention)
end