Class: Google::Apis::RedisV1beta1::Backup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Backup of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backup

Returns a new instance of Backup.



506
507
508
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_filesArray<Google::Apis::RedisV1beta1::BackupFile>

Output only. List of backup files of the backup. Corresponds to the JSON property backupFiles



432
433
434
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 432

def backup_files
  @backup_files
end

#backup_typeString

Output only. Type of the backup. Corresponds to the JSON property backupType

Returns:

  • (String)


437
438
439
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 437

def backup_type
  @backup_type
end

#clusterString

Output only. Cluster resource path of this backup. Corresponds to the JSON property cluster

Returns:

  • (String)


442
443
444
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 442

def cluster
  @cluster
end

#cluster_uidString

Output only. Cluster uid of this backup. Corresponds to the JSON property clusterUid

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 447

def cluster_uid
  @cluster_uid
end

#create_timeString

Output only. The time when the backup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


452
453
454
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 452

def create_time
  @create_time
end

#encryption_infoGoogle::Apis::RedisV1beta1::EncryptionInfo

EncryptionInfo describes the encryption information of a cluster or a backup. Corresponds to the JSON property encryptionInfo



457
458
459
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 457

def encryption_info
  @encryption_info
end

#engine_versionString

Output only. redis-7.2, valkey-7.5 Corresponds to the JSON property engineVersion

Returns:

  • (String)


462
463
464
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 462

def engine_version
  @engine_version
end

#expire_timeString

Output only. The time when the backup will expire. Corresponds to the JSON property expireTime

Returns:

  • (String)


467
468
469
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 467

def expire_time
  @expire_time
end

#nameString

Identifier. Full resource path of the backup. the last part of the name is the backup id with the following format: [YYYYMMDDHHMMSS]_[Shorted Cluster UID] OR customer specified while backup cluster. Example: 20240515123000_1234 Corresponds to the JSON property name

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 474

def name
  @name
end

#node_typeString

Output only. Node type of the cluster. Corresponds to the JSON property nodeType

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 479

def node_type
  @node_type
end

#replica_countFixnum

Output only. Number of replicas for the cluster. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


484
485
486
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 484

def replica_count
  @replica_count
end

#shard_countFixnum

Output only. Number of shards for the cluster. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


489
490
491
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 489

def shard_count
  @shard_count
end

#stateString

Output only. State of the backup. Corresponds to the JSON property state

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 494

def state
  @state
end

#total_size_bytesFixnum

Output only. Total size of the backup in bytes. Corresponds to the JSON property totalSizeBytes

Returns:

  • (Fixnum)


499
500
501
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 499

def total_size_bytes
  @total_size_bytes
end

#uidString

Output only. System assigned unique identifier of the backup. Corresponds to the JSON property uid

Returns:

  • (String)


504
505
506
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 504

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 511

def update!(**args)
  @backup_files = args[:backup_files] if args.key?(:backup_files)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid)
  @create_time = args[:create_time] if args.key?(:create_time)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @engine_version = args[:engine_version] if args.key?(:engine_version)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @node_type = args[:node_type] if args.key?(:node_type)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @state = args[:state] if args.key?(:state)
  @total_size_bytes = args[:total_size_bytes] if args.key?(:total_size_bytes)
  @uid = args[:uid] if args.key?(:uid)
end