Class: Google::Apis::RedisV1beta1::BackupCollection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

BackupCollection of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupCollection

Returns a new instance of BackupCollection.



608
609
610
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Output only. The full resource path of the cluster the backup collection belongs to. Example: projects/project/locations/location/clusters/cluster Corresponds to the JSON property cluster

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 565

def cluster
  @cluster
end

#cluster_uidString

Output only. The cluster uid of the backup collection. Corresponds to the JSON property clusterUid

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 570

def cluster_uid
  @cluster_uid
end

#create_timeString

Output only. The time when the backup collection was created. Corresponds to the JSON property createTime

Returns:

  • (String)


575
576
577
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 575

def create_time
  @create_time
end

#kms_keyString

Output only. The KMS key used to encrypt the backups under this backup collection. Corresponds to the JSON property kmsKey

Returns:

  • (String)


581
582
583
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 581

def kms_key
  @kms_key
end

#last_backup_timeString

Output only. The last time a backup was created in the backup collection. Corresponds to the JSON property lastBackupTime

Returns:

  • (String)


586
587
588
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 586

def last_backup_time
  @last_backup_time
end

#nameString

Identifier. Full resource path of the backup collection. Corresponds to the JSON property name

Returns:

  • (String)


591
592
593
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 591

def name
  @name
end

#total_backup_countFixnum

Output only. Total number of backups in the backup collection. Corresponds to the JSON property totalBackupCount

Returns:

  • (Fixnum)


596
597
598
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 596

def total_backup_count
  @total_backup_count
end

#total_backup_size_bytesFixnum

Output only. Total size of all backups in the backup collection. Corresponds to the JSON property totalBackupSizeBytes

Returns:

  • (Fixnum)


601
602
603
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 601

def total_backup_size_bytes
  @total_backup_size_bytes
end

#uidString

Output only. System assigned unique identifier of the backup collection. Corresponds to the JSON property uid

Returns:

  • (String)


606
607
608
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 606

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



613
614
615
616
617
618
619
620
621
622
623
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 613

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid)
  @create_time = args[:create_time] if args.key?(:create_time)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @last_backup_time = args[:last_backup_time] if args.key?(:last_backup_time)
  @name = args[:name] if args.key?(:name)
  @total_backup_count = args[:total_backup_count] if args.key?(:total_backup_count)
  @total_backup_size_bytes = args[:total_backup_size_bytes] if args.key?(:total_backup_size_bytes)
  @uid = args[:uid] if args.key?(:uid)
end