Class: Google::Apis::RedisV1beta1::BackupDrMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDrMetadata

Returns a new instance of BackupDrMetadata.



718
719
720
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::RedisV1beta1::BackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



690
691
692
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 690

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::RedisV1beta1::BackupRun

A backup run. Corresponds to the JSON property backupRun



695
696
697
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 695

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::RedisV1beta1::BackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



701
702
703
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 701

def backupdr_configuration
  @backupdr_configuration
end

#full_resource_nameString

Required. Full resource name of this instance. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


706
707
708
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 706

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time backup configuration was refreshed. Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 711

def last_refresh_time
  @last_refresh_time
end

#resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



716
717
718
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 716

def resource_id
  @resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



723
724
725
726
727
728
729
730
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 723

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
end