Class: Google::Apis::RedisV1beta1::BackupRun
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::BackupRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
A backup run.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time the backup operation completed.
-
#error ⇒ Google::Apis::RedisV1beta1::OperationError
An error that occurred during a backup creation operation.
-
#start_time ⇒ String
The time the backup operation started.
-
#status ⇒ String
The status of this run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupRun
constructor
A new instance of BackupRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupRun
Returns a new instance of BackupRun.
495 496 497 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time the backup operation completed. REQUIRED
Corresponds to the JSON property endTime
478 479 480 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 478 def end_time @end_time end |
#error ⇒ Google::Apis::RedisV1beta1::OperationError
An error that occurred during a backup creation operation.
Corresponds to the JSON property error
483 484 485 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 483 def error @error end |
#start_time ⇒ String
The time the backup operation started. REQUIRED
Corresponds to the JSON property startTime
488 489 490 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 488 def start_time @start_time end |
#status ⇒ String
The status of this run. REQUIRED
Corresponds to the JSON property status
493 494 495 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 493 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
500 501 502 503 504 505 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 500 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) end |