Class: Google::Apis::RedisV1beta1::ClusterAclPolicyAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

ClusterAclPolicyAttachment stores the ACL policy status for an attached cluster for the revisions successfully applied, under application or failed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterAclPolicyAttachment

Returns a new instance of ClusterAclPolicyAttachment.



1186
1187
1188
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_policy_revision_statusesArray<Google::Apis::RedisV1beta1::AclPolicyRevisionStatus>

Output only. A list of status for various revisions of this ACL policy on the cluster. Corresponds to the JSON property aclPolicyRevisionStatuses



1178
1179
1180
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1178

def acl_policy_revision_statuses
  @acl_policy_revision_statuses
end

#clusterString

Output only. The resource name of the attached Cluster. Format: "projects/ project/locations/location/clusters/cluster" Corresponds to the JSON property cluster

Returns:

  • (String)


1184
1185
1186
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1184

def cluster
  @cluster
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1191
1192
1193
1194
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1191

def update!(**args)
  @acl_policy_revision_statuses = args[:acl_policy_revision_statuses] if args.key?(:acl_policy_revision_statuses)
  @cluster = args[:cluster] if args.key?(:cluster)
end