Class: Google::Apis::RedisV1beta1::ClusterEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

ClusterEndpoint consists of PSC connections that are created as a group in each VPC network for accessing the cluster. In each group, there shall be one connection for each service attachment in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterEndpoint

Returns a new instance of ClusterEndpoint.



1209
1210
1211
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsArray<Google::Apis::RedisV1beta1::ConnectionDetail>

Required. A group of PSC connections. They are created in the same VPC network, one for each service attachment in the cluster. Corresponds to the JSON property connections



1207
1208
1209
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1207

def connections
  @connections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1214
1215
1216
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1214

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
end