Class: Google::Apis::RedisV1beta1::ClusterMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Upcoming maintenance schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterMaintenanceSchedule

Returns a new instance of ClusterMaintenanceSchedule.



908
909
910
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The end time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property endTime

Returns:

  • (String)


900
901
902
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 900

def end_time
  @end_time
end

#start_timeString

Output only. The start time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property startTime

Returns:

  • (String)


906
907
908
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 906

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 913

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end