Class: Google::Apis::RedisV1beta1::Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Compliance

Returns a new instance of Compliance.



1354
1355
1356
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1347

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


1352
1353
1354
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1352

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1359
1360
1361
1362
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1359

def update!(**args)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end