Class: Google::Apis::RedisV1beta1::CrossClusterReplicationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Cross cluster replication config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossClusterReplicationConfig

Returns a new instance of CrossClusterReplicationConfig.



1292
1293
1294
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_roleString

Output only. The role of the cluster in cross cluster replication. Corresponds to the JSON property clusterRole

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1267

def cluster_role
  @cluster_role
end

#membershipGoogle::Apis::RedisV1beta1::Membership

An output only view of all the member clusters participating in the cross cluster replication. Corresponds to the JSON property membership



1273
1274
1275
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1273

def membership
  @membership
end

#primary_clusterGoogle::Apis::RedisV1beta1::RemoteCluster

Details of the remote cluster associated with this cluster in a cross cluster replication setup. Corresponds to the JSON property primaryCluster



1279
1280
1281
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1279

def primary_cluster
  @primary_cluster
end

#secondary_clustersArray<Google::Apis::RedisV1beta1::RemoteCluster>

List of secondary clusters that are replicating from this primary cluster. This field is only set for a primary cluster. Corresponds to the JSON property secondaryClusters



1285
1286
1287
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1285

def secondary_clusters
  @secondary_clusters
end

#update_timeString

Output only. The last time cross cluster replication config was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1290
1291
1292
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1290

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1297
1298
1299
1300
1301
1302
1303
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1297

def update!(**args)
  @cluster_role = args[:cluster_role] if args.key?(:cluster_role)
  @membership = args[:membership] if args.key?(:membership)
  @primary_cluster = args[:primary_cluster] if args.key?(:primary_cluster)
  @secondary_clusters = args[:secondary_clusters] if args.key?(:secondary_clusters)
  @update_time = args[:update_time] if args.key?(:update_time)
end