Class: Google::Apis::RedisV1beta1::DatabaseResourceFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceFeed

Returns a new instance of DatabaseResourceFeed.



1575
1576
1577
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupdr_metadataGoogle::Apis::RedisV1beta1::BackupDrMetadata

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource. Corresponds to the JSON property backupdrMetadata



1514
1515
1516
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1514

def 
  @backupdr_metadata
end

#config_based_signal_dataGoogle::Apis::RedisV1beta1::ConfigBasedSignalData

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases. Corresponds to the JSON property configBasedSignalData



1521
1522
1523
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1521

def config_based_signal_data
  @config_based_signal_data
end

#database_resource_signal_dataGoogle::Apis::RedisV1beta1::DatabaseResourceSignalData

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10 Corresponds to the JSON property databaseResourceSignalData



1528
1529
1530
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1528

def database_resource_signal_data
  @database_resource_signal_data
end

#feed_timestampString

Required. Timestamp when feed is generated. Corresponds to the JSON property feedTimestamp

Returns:

  • (String)


1533
1534
1535
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1533

def feed_timestamp
  @feed_timestamp
end

#feed_typeString

Required. Type feed to be ingested into condor Corresponds to the JSON property feedType

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1538

def feed_type
  @feed_type
end

#observability_metric_dataGoogle::Apis::RedisV1beta1::ObservabilityMetricData

Observability metric data. Corresponds to the JSON property observabilityMetricData



1543
1544
1545
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1543

def observability_metric_data
  @observability_metric_data
end

#recommendation_signal_dataGoogle::Apis::RedisV1beta1::DatabaseResourceRecommendationSignalData

Common model for database resource recommendation signal data. Corresponds to the JSON property recommendationSignalData



1548
1549
1550
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1548

def recommendation_signal_data
  @recommendation_signal_data
end

#resource_health_signal_dataGoogle::Apis::RedisV1beta1::DatabaseResourceHealthSignalData

Common model for database resource health signal data. Corresponds to the JSON property resourceHealthSignalData



1553
1554
1555
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1553

def resource_health_signal_data
  @resource_health_signal_data
end

#resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



1558
1559
1560
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1558

def resource_id
  @resource_id
end

#resource_metadataGoogle::Apis::RedisV1beta1::DatabaseResourceMetadata

Common model for database resource instance metadata. Next ID: 35 Corresponds to the JSON property resourceMetadata



1563
1564
1565
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1563

def 
  @resource_metadata
end

#skip_ingestionBoolean Also known as: skip_ingestion?

Optional. If true, the feed won't be ingested by DB Center. This indicates that the feed is intentionally skipped. For example, BackupDR feeds are only needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB). Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can be skipped. Corresponds to the JSON property skipIngestion

Returns:

  • (Boolean)


1572
1573
1574
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1572

def skip_ingestion
  @skip_ingestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1580

def update!(**args)
  @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata)
  @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data)
  @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data)
  @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp)
  @feed_type = args[:feed_type] if args.key?(:feed_type)
  @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data)
  @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data)
  @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata)
  @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion)
end