Class: Google::Apis::RedisV1beta1::DatabaseResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Common model for database resource instance metadata. Next ID: 35

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceMetadata

Returns a new instance of DatabaseResourceMetadata.



1945
1946
1947
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_metadataHash<String,Object>

Field to ingest additional metadata whichd does not support proto format. Corresponds to the JSON property additionalMetadata

Returns:

  • (Hash<String,Object>)


1766
1767
1768
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1766

def 
  @additional_metadata
end

#availability_configurationGoogle::Apis::RedisV1beta1::AvailabilityConfiguration

Configuration for availability of database instance Corresponds to the JSON property availabilityConfiguration



1771
1772
1773
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1771

def availability_configuration
  @availability_configuration
end

#backup_configurationGoogle::Apis::RedisV1beta1::BackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



1776
1777
1778
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1776

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::RedisV1beta1::BackupRun

A backup run. Corresponds to the JSON property backupRun



1781
1782
1783
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1781

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::RedisV1beta1::BackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



1787
1788
1789
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1787

def backupdr_configuration
  @backupdr_configuration
end

#creation_timeString

The creation time of the resource, i.e. the time when resource is created and recorded in partner service. Corresponds to the JSON property creationTime

Returns:

  • (String)


1793
1794
1795
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1793

def creation_time
  @creation_time
end

#current_stateString

Current state of the instance. Corresponds to the JSON property currentState

Returns:

  • (String)


1798
1799
1800
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1798

def current_state
  @current_state
end

#custom_metadataGoogle::Apis::RedisV1beta1::CustomMetadataData

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data Corresponds to the JSON property customMetadata



1805
1806
1807
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1805

def 
  @custom_metadata
end

#editionString

Optional. Edition represents whether the instance is ENTERPRISE or ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to identify the edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


1812
1813
1814
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1812

def edition
  @edition
end

#entitlementsArray<Google::Apis::RedisV1beta1::Entitlement>

Entitlements associated with the resource Corresponds to the JSON property entitlements



1817
1818
1819
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1817

def entitlements
  @entitlements
end

#expected_stateString

The state that the instance is expected to be in. For example, an instance state can transition to UNHEALTHY due to wrong patch update, while the expected state will remain at the HEALTHY. Corresponds to the JSON property expectedState

Returns:

  • (String)


1824
1825
1826
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1824

def expected_state
  @expected_state
end

#gcbdr_configurationGoogle::Apis::RedisV1beta1::GcbdrConfiguration

GCBDR Configuration for the resource. Corresponds to the JSON property gcbdrConfiguration



1829
1830
1831
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1829

def gcbdr_configuration
  @gcbdr_configuration
end

#idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property id



1834
1835
1836
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1834

def id
  @id
end

#instance_typeString

The type of the instance. Specified at creation time. Corresponds to the JSON property instanceType

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1839

def instance_type
  @instance_type
end

#internal_additional_metadataHash<String,Object>

Field to ingest additional metadata which support proto format. Corresponds to the JSON property internalAdditionalMetadata

Returns:

  • (Hash<String,Object>)


1844
1845
1846
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1844

def 
  @internal_additional_metadata
end

#ip_addressGoogle::Apis::RedisV1beta1::IpAddress

Used to send IP address information for a database resource. Corresponds to the JSON property ipAddress



1849
1850
1851
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1849

def ip_address
  @ip_address
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Optional. Whether deletion protection is enabled for this resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


1854
1855
1856
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1854

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#locationString

The resource location. REQUIRED Corresponds to the JSON property location

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1860

def location
  @location
end

#machine_configurationGoogle::Apis::RedisV1beta1::MachineConfiguration

MachineConfiguration describes the configuration of a machine specific to Database Resource. Corresponds to the JSON property machineConfiguration



1866
1867
1868
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1866

def machine_configuration
  @machine_configuration
end

#maintenance_infoGoogle::Apis::RedisV1beta1::ResourceMaintenanceInfo

MaintenanceInfo to capture the maintenance details of database resource. Corresponds to the JSON property maintenanceInfo



1871
1872
1873
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1871

def maintenance_info
  @maintenance_info
end

#modesArray<String>

Optional. The modes of the database resource. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


1876
1877
1878
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1876

def modes
  @modes
end

#primary_resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property primaryResourceId



1881
1882
1883
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1881

def primary_resource_id
  @primary_resource_id
end

#primary_resource_locationString

Primary resource location. REQUIRED if the immediate parent exists when first time resource is getting ingested, otherwise optional. Corresponds to the JSON property primaryResourceLocation

Returns:

  • (String)


1887
1888
1889
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1887

def primary_resource_location
  @primary_resource_location
end

#productGoogle::Apis::RedisV1beta1::Product

Product specification for Condor resources. Corresponds to the JSON property product



1892
1893
1894
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1892

def product
  @product
end

#resource_containerString

Closest parent Cloud Resource Manager container of this resource. It must be resource name of a Cloud Resource Manager project with the format of "/", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1899
1900
1901
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1899

def resource_container
  @resource_container
end

#resource_flagsArray<Google::Apis::RedisV1beta1::ResourceFlags>

Optional. List of resource flags for the database resource. Corresponds to the JSON property resourceFlags



1904
1905
1906
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1904

def resource_flags
  @resource_flags
end

#resource_nameString

Required. Different from DatabaseResourceId.unique_id, a resource name can be reused over time. That is, after a resource named "ABC" is deleted, the name " ABC" can be used to to create a new resource within the same source. Resource name to follow CAIS resource_name format as noted here go/condor-common- datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


1913
1914
1915
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1913

def resource_name
  @resource_name
end

#suspension_reasonString

Optional. Suspension reason for the resource. Corresponds to the JSON property suspensionReason

Returns:

  • (String)


1918
1919
1920
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1918

def suspension_reason
  @suspension_reason
end

#tags_setGoogle::Apis::RedisV1beta1::Tags

Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag. Corresponds to the JSON property tagsSet



1925
1926
1927
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1925

def tags_set
  @tags_set
end

#updation_timeString

The time at which the resource was updated and recorded at partner service. Corresponds to the JSON property updationTime

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1930

def updation_time
  @updation_time
end

#user_label_setGoogle::Apis::RedisV1beta1::UserLabels

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels. Corresponds to the JSON property userLabelSet



1937
1938
1939
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1937

def user_label_set
  @user_label_set
end

#zoneString

The resource zone. This is only applicable for zonal resources and will be empty for regional and multi-regional resources. Corresponds to the JSON property zone

Returns:

  • (String)


1943
1944
1945
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1943

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1950

def update!(**args)
  @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata)
  @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @current_state = args[:current_state] if args.key?(:current_state)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @edition = args[:edition] if args.key?(:edition)
  @entitlements = args[:entitlements] if args.key?(:entitlements)
  @expected_state = args[:expected_state] if args.key?(:expected_state)
  @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration)
  @id = args[:id] if args.key?(:id)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @internal_additional_metadata = args[:internal_additional_metadata] if args.key?(:internal_additional_metadata)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @location = args[:location] if args.key?(:location)
  @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration)
  @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info)
  @modes = args[:modes] if args.key?(:modes)
  @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id)
  @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location)
  @product = args[:product] if args.key?(:product)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_flags = args[:resource_flags] if args.key?(:resource_flags)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @tags_set = args[:tags_set] if args.key?(:tags_set)
  @updation_time = args[:updation_time] if args.key?(:updation_time)
  @user_label_set = args[:user_label_set] if args.key?(:user_label_set)
  @zone = args[:zone] if args.key?(:zone)
end