Class: Google::Apis::RedisV1beta1::DatabaseResourceSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceSignalData

Returns a new instance of DatabaseResourceSignalData.



2112
2113
2114
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_runGoogle::Apis::RedisV1beta1::BackupRun

A backup run. Corresponds to the JSON property backupRun



2068
2069
2070
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2068

def backup_run
  @backup_run
end

#full_resource_nameString

Required. Full Resource name of the source resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


2073
2074
2075
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2073

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time signal was refreshed Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


2078
2079
2080
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2078

def last_refresh_time
  @last_refresh_time
end

#locationString

Required. Resource location. Corresponds to the JSON property location

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2083

def location
  @location
end

#resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



2088
2089
2090
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2088

def resource_id
  @resource_id
end

#signal_bool_valueBoolean Also known as: signal_bool_value?

Deprecated: Use signal_metadata_list instead. Corresponds to the JSON property signalBoolValue

Returns:

  • (Boolean)


2093
2094
2095
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2093

def signal_bool_value
  @signal_bool_value
end

#signal_metadata_listArray<Google::Apis::RedisV1beta1::SignalMetadata>

This will support array of OneOf signal metadata information for a given signal type. Corresponds to the JSON property signalMetadataList



2100
2101
2102
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2100

def 
  @signal_metadata_list
end

#signal_stateString

Required. Output only. Signal state of the signal Corresponds to the JSON property signalState

Returns:

  • (String)


2105
2106
2107
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2105

def signal_state
  @signal_state
end

#signal_typeString

Required. Signal type of the signal Corresponds to the JSON property signalType

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2110

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2117

def update!(**args)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @location = args[:location] if args.key?(:location)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value)
  @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list)
  @signal_state = args[:signal_state] if args.key?(:signal_state)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end