Class: Google::Apis::RedisV1beta1::GoogleCloudCommonOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::GoogleCloudCommonOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCommonOperationMetadata
constructor
A new instance of GoogleCloudCommonOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCommonOperationMetadata
Returns a new instance of GoogleCloudCommonOperationMetadata.
2075 2076 2077 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
2039 2040 2041 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2039 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelRequested
2047 2048 2049 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2047 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
2053 2054 2055 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2053 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
2058 2059 2060 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2058 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
2063 2064 2065 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2063 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
2068 2069 2070 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2068 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
2073 2074 2075 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2073 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2080 2081 2082 2083 2084 2085 2086 2087 2088 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2080 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |