Class: Google::Apis::RedisV1beta1::IpAddress
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::IpAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Used to send IP address information for a database resource.
Instance Attribute Summary collapse
-
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud (VPC).
-
#public_ip ⇒ String
The public IP address assigned to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpAddress
constructor
A new instance of IpAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpAddress
Returns a new instance of IpAddress.
2971 2972 2973 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud
(VPC). This IP is only reachable from within the same VPC network. Stored in
standard string format (e.g., "10.0.0.2").
Corresponds to the JSON property privateIp
2963 2964 2965 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2963 def private_ip @private_ip end |
#public_ip ⇒ String
The public IP address assigned to the resource. This IP is reachable from the
internet. Stored in standard string format (e.g., "34.72.1.1").
Corresponds to the JSON property publicIp
2969 2970 2971 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2969 def public_ip @public_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2976 2977 2978 2979 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2976 def update!(**args) @private_ip = args[:private_ip] if args.key?(:private_ip) @public_ip = args[:public_ip] if args.key?(:public_ip) end |