Class: Google::Apis::RedisV1beta1::ListAuthTokensResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ListAuthTokensResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Response message for ListAuthTokens.
Instance Attribute Summary collapse
-
#auth_tokens ⇒ Array<Google::Apis::RedisV1beta1::AuthToken>
A list of auth tokens in the project.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAuthTokensResponse
constructor
A new instance of ListAuthTokensResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAuthTokensResponse
Returns a new instance of ListAuthTokensResponse.
2858 2859 2860 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_tokens ⇒ Array<Google::Apis::RedisV1beta1::AuthToken>
A list of auth tokens in the project.
Corresponds to the JSON property authTokens
2845 2846 2847 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2845 def auth_tokens @auth_tokens end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
2851 2852 2853 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2851 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Auth tokens that could not be reached.
Corresponds to the JSON property unreachable
2856 2857 2858 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2856 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2863 2864 2865 2866 2867 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2863 def update!(**args) @auth_tokens = args[:auth_tokens] if args.key?(:auth_tokens) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |