Class: Google::Apis::RedisV1beta1::ListBackupCollectionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Response for ListBackupCollections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupCollectionsResponse

Returns a new instance of ListBackupCollectionsResponse.



2851
2852
2853
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_collectionsArray<Google::Apis::RedisV1beta1::BackupCollection>

A list of backupCollections in the project. If the location_id in the parent field of the request is "-", all regions available to the project are queried, and the results aggregated. If in such an aggregated query a location is unavailable, a placeholder backupCollection entry is included in the response with the name field set to a value of the form projects/project_id/ locations/location_id/backupCollections/- and the status field set to ERROR and status_message field set to "location not available for ListBackupCollections". Corresponds to the JSON property backupCollections



2838
2839
2840
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2838

def backup_collections
  @backup_collections
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2844
2845
2846
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2844

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2849
2850
2851
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2849

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2856
2857
2858
2859
2860
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2856

def update!(**args)
  @backup_collections = args[:backup_collections] if args.key?(:backup_collections)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end