Class: Google::Apis::RedisV1beta1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Response for ListBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



2928
2929
2930
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::RedisV1beta1::Backup>

A list of backups in the project. Corresponds to the JSON property backups



2915
2916
2917
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2915

def backups
  @backups
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2921
2922
2923
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2921

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Backups that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2926
2927
2928
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2926

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2933
2934
2935
2936
2937
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2933

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end