Class: Google::Apis::RedisV1beta1::ListTokenAuthUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Response message for ListTokenAuthUsers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTokenAuthUsersResponse

Returns a new instance of ListTokenAuthUsersResponse.



3098
3099
3100
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3086
3087
3088
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3086

def next_page_token
  @next_page_token
end

#token_auth_usersArray<Google::Apis::RedisV1beta1::TokenAuthUser>

A list of token auth users in the project. Corresponds to the JSON property tokenAuthUsers



3091
3092
3093
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3091

def token_auth_users
  @token_auth_users
end

#unreachableArray<String>

Unordered list. Token auth users that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3096
3097
3098
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3096

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3103
3104
3105
3106
3107
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3103

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @token_auth_users = args[:token_auth_users] if args.key?(:token_auth_users)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end