Class: Google::Apis::RedisV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Pre-defined metadata fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



3576
3577
3578
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3540

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3545
3546
3547
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3545

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


3550
3551
3552
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3550

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


3558
3559
3560
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3558

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3564

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3569

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


3574
3575
3576
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3574

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3581

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end