Class: Google::Apis::RedisV1beta1::Product
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::Product
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Product specification for Condor resources.
Instance Attribute Summary collapse
-
#engine ⇒ String
The specific engine that the underlying database is running.
-
#minor_version ⇒ String
Minor version of the underlying database engine.
-
#type ⇒ String
Type of specific database product.
-
#version ⇒ String
Version of the underlying database engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Product
constructor
A new instance of Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Product
Returns a new instance of Product.
3637 3638 3639 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#engine ⇒ String
The specific engine that the underlying database is running.
Corresponds to the JSON property engine
3617 3618 3619 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3617 def engine @engine end |
#minor_version ⇒ String
Minor version of the underlying database engine. Example values: For MySQL, it
could be "8.0.32", "5.7.32" etc.. For Postgres, it could be "14.3", "15.3" etc.
.
Corresponds to the JSON property minorVersion
3624 3625 3626 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3624 def minor_version @minor_version end |
#type ⇒ String
Type of specific database product. It could be CloudSQL, AlloyDB etc..
Corresponds to the JSON property type
3629 3630 3631 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3629 def type @type end |
#version ⇒ String
Version of the underlying database engine. Example values: For MySQL, it could
be "8.0", "5.7" etc.. For Postgres, it could be "14", "15" etc..
Corresponds to the JSON property version
3635 3636 3637 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3635 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3642 3643 3644 3645 3646 3647 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3642 def update!(**args) @engine = args[:engine] if args.key?(:engine) @minor_version = args[:minor_version] if args.key?(:minor_version) @type = args[:type] if args.key?(:type) @version = args[:version] if args.key?(:version) end |