Class: Google::Apis::RedisV1beta1::PscConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Details of consumer resources in a PSC connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConnection

Returns a new instance of PscConnection.



4055
4056
4057
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Required. The IP allocated on the consumer network for the PSC forwarding rule. Corresponds to the JSON property address

Returns:

  • (String)


4004
4005
4006
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4004

def address
  @address
end

#connection_typeString

Output only. Type of the PSC connection. Corresponds to the JSON property connectionType

Returns:

  • (String)


4009
4010
4011
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4009

def connection_type
  @connection_type
end

#forwarding_ruleString

Required. The URI of the consumer side forwarding rule. Example: projects/ projectNumOrId/regions/us-east1/forwardingRules/resourceId. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4015

def forwarding_rule
  @forwarding_rule
end

#networkString

Required. The consumer network where the IP address resides, in the form of projects/project_id/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4021

def network
  @network
end

#portFixnum

Output only. port will only be set for Primary/Reader or Discovery endpoint. Corresponds to the JSON property port

Returns:

  • (Fixnum)


4026
4027
4028
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4026

def port
  @port
end

#project_idString

Optional. Project ID of the consumer project where the forwarding rule is created in. Corresponds to the JSON property projectId

Returns:

  • (String)


4032
4033
4034
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4032

def project_id
  @project_id
end

#psc_connection_idString

Required. The PSC connection id of the forwarding rule connected to the service attachment. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4038

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Output only. The status of the PSC connection. Please note that this value is updated periodically. To get the latest status of a PSC connection, follow https://cloud.google.com/vpc/docs/configure-private-service-connect-services# endpoint-details. Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


4046
4047
4048
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4046

def psc_connection_status
  @psc_connection_status
end

#service_attachmentString

Required. The service attachment which is the target of the PSC connection, in the form of projects/project-id/regions/region/serviceAttachments/service- attachment-id. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4053

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4060

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @network = args[:network] if args.key?(:network)
  @port = args[:port] if args.key?(:port)
  @project_id = args[:project_id] if args.key?(:project_id)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end