Class: Google::Apis::RedisV1beta1::PscServiceAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Configuration of a service attachment of the cluster, for creating PSC connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscServiceAttachment

Returns a new instance of PscServiceAttachment.



3833
3834
3835
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_typeString

Output only. Type of a PSC connection targeting this service attachment. Corresponds to the JSON property connectionType

Returns:

  • (String)


3825
3826
3827
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3825

def connection_type
  @connection_type
end

#service_attachmentString

Output only. Service attachment URI which your self-created PscConnection should use as target Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3831

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3838
3839
3840
3841
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3838

def update!(**args)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end