Class: Google::Apis::RedisV1beta1::RdbConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Configuration of the RDB based persistence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RdbConfig

Returns a new instance of RdbConfig.



4116
4117
4118
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rdb_snapshot_periodString

Optional. Period between RDB snapshots. Corresponds to the JSON property rdbSnapshotPeriod

Returns:

  • (String)


4107
4108
4109
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4107

def rdb_snapshot_period
  @rdb_snapshot_period
end

#rdb_snapshot_start_timeString

Optional. The time that the first snapshot was/will be attempted, and to which future snapshots will be aligned. If not provided, the current time will be used. Corresponds to the JSON property rdbSnapshotStartTime

Returns:

  • (String)


4114
4115
4116
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4114

def rdb_snapshot_start_time
  @rdb_snapshot_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4121
4122
4123
4124
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4121

def update!(**args)
  @rdb_snapshot_period = args[:rdb_snapshot_period] if args.key?(:rdb_snapshot_period)
  @rdb_snapshot_start_time = args[:rdb_snapshot_start_time] if args.key?(:rdb_snapshot_start_time)
end