Class: Google::Apis::RedisV1beta1::RemoteCluster
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::RemoteCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Details of the remote cluster associated with this cluster in a cross cluster replication setup.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteCluster
constructor
A new instance of RemoteCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteCluster
Returns a new instance of RemoteCluster.
4207 4208 4209 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Output only. The full resource path of the remote cluster in the format:
projects//locations//clusters/
Corresponds to the JSON property cluster
4200 4201 4202 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4200 def cluster @cluster end |
#uid ⇒ String
Output only. The unique identifier of the remote cluster.
Corresponds to the JSON property uid
4205 4206 4207 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4205 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4212 4213 4214 4215 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4212 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @uid = args[:uid] if args.key?(:uid) end |