Class: Google::Apis::RedisV1beta1::TokenAuthUser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Represents a token based auth user for the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TokenAuthUser

Returns a new instance of TokenAuthUser.



4534
4535
4536
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the token based auth user. Format: projects/ project/locations/location/clusters/cluster/tokenAuthUsers/ token_auth_user Corresponds to the JSON property name

Returns:

  • (String)


4527
4528
4529
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4527

def name
  @name
end

#stateString

Output only. The state of the token based auth user. Corresponds to the JSON property state

Returns:

  • (String)


4532
4533
4534
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4532

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4539
4540
4541
4542
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4539

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end