Class: Google::Apis::RedisV1beta1::WeeklyMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Time window in which disruptive maintenance updates occur. Non-disruptive updates can occur inside or outside this window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyMaintenanceWindow

Returns a new instance of WeeklyMaintenanceWindow.



4914
4915
4916
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Required. The day of week that maintenance updates occur. Corresponds to the JSON property day

Returns:

  • (String)


4899
4900
4901
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4899

def day
  @day
end

#durationString

Output only. Duration of the maintenance window. The current window is fixed at 1 hour. Corresponds to the JSON property duration

Returns:

  • (String)


4905
4906
4907
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4905

def duration
  @duration
end

#start_timeGoogle::Apis::RedisV1beta1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



4912
4913
4914
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4912

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4919
4920
4921
4922
4923
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4919

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end