Class: Google::Apis::RedisV1beta1::Backup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Backup of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backup

Returns a new instance of Backup.



362
363
364
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_filesArray<Google::Apis::RedisV1beta1::BackupFile>

Output only. List of backup files of the backup. Corresponds to the JSON property backupFiles



288
289
290
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 288

def backup_files
  @backup_files
end

#backup_typeString

Output only. Type of the backup. Corresponds to the JSON property backupType

Returns:

  • (String)


293
294
295
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 293

def backup_type
  @backup_type
end

#clusterString

Output only. Cluster resource path of this backup. Corresponds to the JSON property cluster

Returns:

  • (String)


298
299
300
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 298

def cluster
  @cluster
end

#cluster_uidString

Output only. Cluster uid of this backup. Corresponds to the JSON property clusterUid

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 303

def cluster_uid
  @cluster_uid
end

#create_timeString

Output only. The time when the backup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 308

def create_time
  @create_time
end

#encryption_infoGoogle::Apis::RedisV1beta1::EncryptionInfo

EncryptionInfo describes the encryption information of a cluster or a backup. Corresponds to the JSON property encryptionInfo



313
314
315
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 313

def encryption_info
  @encryption_info
end

#engine_versionString

Output only. redis-7.2, valkey-7.5 Corresponds to the JSON property engineVersion

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 318

def engine_version
  @engine_version
end

#expire_timeString

Output only. The time when the backup will expire. Corresponds to the JSON property expireTime

Returns:

  • (String)


323
324
325
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 323

def expire_time
  @expire_time
end

#nameString

Identifier. Full resource path of the backup. the last part of the name is the backup id with the following format: [YYYYMMDDHHMMSS]_[Shorted Cluster UID] OR customer specified while backup cluster. Example: 20240515123000_1234 Corresponds to the JSON property name

Returns:

  • (String)


330
331
332
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 330

def name
  @name
end

#node_typeString

Output only. Node type of the cluster. Corresponds to the JSON property nodeType

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 335

def node_type
  @node_type
end

#replica_countFixnum

Output only. Number of replicas for the cluster. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


340
341
342
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 340

def replica_count
  @replica_count
end

#shard_countFixnum

Output only. Number of shards for the cluster. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


345
346
347
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 345

def shard_count
  @shard_count
end

#stateString

Output only. State of the backup. Corresponds to the JSON property state

Returns:

  • (String)


350
351
352
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 350

def state
  @state
end

#total_size_bytesFixnum

Output only. Total size of the backup in bytes. Corresponds to the JSON property totalSizeBytes

Returns:

  • (Fixnum)


355
356
357
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 355

def total_size_bytes
  @total_size_bytes
end

#uidString

Output only. System assigned unique identifier of the backup. Corresponds to the JSON property uid

Returns:

  • (String)


360
361
362
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 360

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 367

def update!(**args)
  @backup_files = args[:backup_files] if args.key?(:backup_files)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid)
  @create_time = args[:create_time] if args.key?(:create_time)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @engine_version = args[:engine_version] if args.key?(:engine_version)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @node_type = args[:node_type] if args.key?(:node_type)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @state = args[:state] if args.key?(:state)
  @total_size_bytes = args[:total_size_bytes] if args.key?(:total_size_bytes)
  @uid = args[:uid] if args.key?(:uid)
end