Class: Google::Apis::RedisV1beta1::BackupCollection
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::BackupCollection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
BackupCollection of a cluster.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Output only.
-
#cluster_uid ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#kms_key ⇒ String
Output only.
-
#last_backup_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#total_backup_count ⇒ Fixnum
Output only.
-
#total_backup_size_bytes ⇒ Fixnum
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupCollection
constructor
A new instance of BackupCollection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupCollection
Returns a new instance of BackupCollection.
315 316 317 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Output only. The full resource path of the cluster the backup collection
belongs to. Example: projects/project/locations/location/clusters/cluster
Corresponds to the JSON property cluster
272 273 274 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 272 def cluster @cluster end |
#cluster_uid ⇒ String
Output only. The cluster uid of the backup collection.
Corresponds to the JSON property clusterUid
277 278 279 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 277 def cluster_uid @cluster_uid end |
#create_time ⇒ String
Output only. The time when the backup collection was created.
Corresponds to the JSON property createTime
282 283 284 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 282 def create_time @create_time end |
#kms_key ⇒ String
Output only. The KMS key used to encrypt the backups under this backup
collection.
Corresponds to the JSON property kmsKey
288 289 290 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 288 def kms_key @kms_key end |
#last_backup_time ⇒ String
Output only. The last time a backup was created in the backup collection.
Corresponds to the JSON property lastBackupTime
293 294 295 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 293 def last_backup_time @last_backup_time end |
#name ⇒ String
Identifier. Full resource path of the backup collection.
Corresponds to the JSON property name
298 299 300 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 298 def name @name end |
#total_backup_count ⇒ Fixnum
Output only. Total number of backups in the backup collection.
Corresponds to the JSON property totalBackupCount
303 304 305 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 303 def total_backup_count @total_backup_count end |
#total_backup_size_bytes ⇒ Fixnum
Output only. Total size of all backups in the backup collection.
Corresponds to the JSON property totalBackupSizeBytes
308 309 310 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 308 def total_backup_size_bytes @total_backup_size_bytes end |
#uid ⇒ String
Output only. System assigned unique identifier of the backup collection.
Corresponds to the JSON property uid
313 314 315 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 313 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 320 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid) @create_time = args[:create_time] if args.key?(:create_time) @kms_key = args[:kms_key] if args.key?(:kms_key) @last_backup_time = args[:last_backup_time] if args.key?(:last_backup_time) @name = args[:name] if args.key?(:name) @total_backup_count = args[:total_backup_count] if args.key?(:total_backup_count) @total_backup_size_bytes = args[:total_backup_size_bytes] if args.key?(:total_backup_size_bytes) @uid = args[:uid] if args.key?(:uid) end |