Class: Google::Apis::RedisV1beta1::BackupDrMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::BackupDrMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupDrMetadata
constructor
A new instance of BackupDrMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupDrMetadata
Returns a new instance of BackupDrMetadata.
425 426 427 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
397 398 399 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 397 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
402 403 404 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 402 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
408 409 410 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 408 def backupdr_configuration @backupdr_configuration end |
#full_resource_name ⇒ String
Required. Full resource name of this instance.
Corresponds to the JSON property fullResourceName
413 414 415 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 413 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time backup configuration was refreshed.
Corresponds to the JSON property lastRefreshTime
418 419 420 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 418 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
423 424 425 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 423 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 430 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) end |