Class: Google::Apis::RedisV1beta1::CloudRedisService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::RedisV1beta1::CloudRedisService
- Defined in:
- lib/google/apis/redis_v1beta1/service.rb
Overview
Google Cloud Memorystore for Redis API
Creates and manages Redis instances on the Google Cloud Platform.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://redis.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#backup_cluster(name, backup_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Backup Redis Cluster.
-
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Creates a Redis cluster based on the specified properties.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Creates a Redis instance based on the specified tier and memory size.
-
#delete_project_location_backup_collection_backup(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific backup.
-
#delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific Redis cluster.
-
#delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific Redis instance.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Empty
Deletes a long-running operation.
-
#export_backup(name, export_backup_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Exports a specific backup to a customer target Cloud Storage URI.
-
#export_instance(name, export_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Export Redis instance data into a Redis RDB format file in Cloud Storage.
-
#failover_instance(name, failover_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Initiates a failover of the primary node to current replica node for a specific STANDARD tier Cloud Memorystore for Redis instance.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Location
Gets information about a location.
-
#get_project_location_backup_collection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::BackupCollection
Get a backup collection.
-
#get_project_location_backup_collection_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Backup
Gets the details of a specific backup.
-
#get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Cluster
Gets the details of a specific Redis cluster.
-
#get_project_location_cluster_certificate_authority(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::CertificateAuthority
Gets the details of certificate authority information for Redis cluster.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Instance
Gets the details of a specific Redis instance.
-
#get_project_location_instance_auth_string(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::InstanceAuthString
Gets the AUTH string for a Redis instance.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Gets the latest state of a long-running operation.
-
#import_instance(name, import_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Import a Redis RDB snapshot file from Cloud Storage into a Redis instance.
-
#initialize ⇒ CloudRedisService
constructor
A new instance of CloudRedisService.
-
#list_project_location_backup_collection_backups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListBackupsResponse
Lists all backups owned by a backup collection.
-
#list_project_location_backup_collections(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListBackupCollectionsResponse
Lists all backup collections owned by a consumer project in either the specified location (region) or all locations.
-
#list_project_location_clusters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListClustersResponse
Lists all Redis clusters owned by a project in either the specified location ( region) or all locations.
-
#list_project_location_instances(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListInstancesResponse
Lists all Redis instances owned by a project in either the specified location ( region) or all locations.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Updates the metadata and configuration of a specific Redis cluster.
-
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Updates the metadata and configuration of a specific Redis instance.
-
#reschedule_cluster_maintenance(name, reschedule_cluster_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Reschedules upcoming maintenance event.
-
#reschedule_instance_maintenance(name, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Reschedule maintenance for a given instance in a given project and location.
-
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Upgrades Redis instance to the newer Redis version specified in the request.
Constructor Details
#initialize ⇒ CloudRedisService
Returns a new instance of CloudRedisService.
47 48 49 50 51 52 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-redis_v1beta1', client_version: Google::Apis::RedisV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#backup_cluster(name, backup_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Backup Redis Cluster. If this is the first time a backup is being created, a backup collection will be created at the backend, and this backup belongs to this collection. Both collection and backup will have a resource name. Backup will be executed for each shard. A replica (primary if nonHA) will be selected to perform the execution. Backup call will be rejected if there is an ongoing backup or update operation. Be aware that during preview, if the cluster's internal software version is too old, critical update will be performed before actual backup. Once the internal software version is updated to the minimum version required by the backup feature, subsequent backups will not require critical update. After preview, there will be no critical update needed for backup.
386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 386 def backup_cluster(name, backup_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:backup', ) command.request_representation = Google::Apis::RedisV1beta1::BackupClusterRequest::Representation command.request_object = backup_cluster_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1126 def cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.response_representation = Google::Apis::RedisV1beta1::Empty::Representation command.response_class = Google::Apis::RedisV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Creates a Redis cluster based on the specified properties. The creation is executed asynchronously and callers may check the returned operation to track its progress. Once the operation is completed the Redis cluster will be fully functional. The completed longrunning.Operation will contain the new cluster object in the response field. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 434 def create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/clusters', ) command.request_representation = Google::Apis::RedisV1beta1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['clusterId'] = cluster_id unless cluster_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Creates a Redis instance based on the specified tier and memory size. By default, the instance is accessible from the project's default network. The creation is executed asynchronously and callers may check the returned operation to track its progress. Once the operation is completed the Redis instance will be fully functional. The completed longrunning.Operation will contain the new instance object in the response field. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
710 711 712 713 714 715 716 717 718 719 720 721 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 710 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/instances', ) command.request_representation = Google::Apis::RedisV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backup_collection_backup(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific backup.
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 233 def delete_project_location_backup_collection_backup(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific Redis cluster. Cluster stops serving and data is deleted.
472 473 474 475 476 477 478 479 480 481 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 472 def delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Deletes a specific Redis instance. Instance stops serving and data is deleted.
745 746 747 748 749 750 751 752 753 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 745 def delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1159 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Empty::Representation command.response_class = Google::Apis::RedisV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_backup(name, export_backup_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Exports a specific backup to a customer target Cloud Storage URI.
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 267 def export_backup(name, export_backup_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:export', ) command.request_representation = Google::Apis::RedisV1beta1::ExportBackupRequest::Representation command.request_object = export_backup_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_instance(name, export_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Export Redis instance data into a Redis RDB format file in Cloud Storage. Redis will continue serving during this operation. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 781 def export_instance(name, export_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:export', ) command.request_representation = Google::Apis::RedisV1beta1::ExportInstanceRequest::Representation command.request_object = export_instance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#failover_instance(name, failover_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Initiates a failover of the primary node to current replica node for a specific STANDARD tier Cloud Memorystore for Redis instance.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 817 def failover_instance(name, failover_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:failover', ) command.request_representation = Google::Apis::RedisV1beta1::FailoverInstanceRequest::Representation command.request_object = failover_instance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Location::Representation command.response_class = Google::Apis::RedisV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backup_collection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::BackupCollection
Get a backup collection.
153 154 155 156 157 158 159 160 161 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 153 def get_project_location_backup_collection(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::BackupCollection::Representation command.response_class = Google::Apis::RedisV1beta1::BackupCollection command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backup_collection_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Backup
Gets the details of a specific backup.
301 302 303 304 305 306 307 308 309 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 301 def get_project_location_backup_collection_backup(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Backup::Representation command.response_class = Google::Apis::RedisV1beta1::Backup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Cluster
Gets the details of a specific Redis cluster.
505 506 507 508 509 510 511 512 513 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 505 def get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Cluster::Representation command.response_class = Google::Apis::RedisV1beta1::Cluster command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cluster_certificate_authority(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::CertificateAuthority
Gets the details of certificate authority information for Redis cluster.
537 538 539 540 541 542 543 544 545 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 537 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::CertificateAuthority::Representation command.response_class = Google::Apis::RedisV1beta1::CertificateAuthority command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Instance
Gets the details of a specific Redis instance.
851 852 853 854 855 856 857 858 859 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 851 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Instance::Representation command.response_class = Google::Apis::RedisV1beta1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_auth_string(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::InstanceAuthString
Gets the AUTH string for a Redis instance. If AUTH is not enabled for the instance the response will be empty. This information is not included in the details returned to GetInstance.
885 886 887 888 889 890 891 892 893 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 885 def get_project_location_instance_auth_string(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/authString', ) command.response_representation = Google::Apis::RedisV1beta1::InstanceAuthString::Representation command.response_class = Google::Apis::RedisV1beta1::InstanceAuthString command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1190 1191 1192 1193 1194 1195 1196 1197 1198 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1190 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_instance(name, import_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Import a Redis RDB snapshot file from Cloud Storage into a Redis instance. Redis may stop serving during this operation. Instance state will be IMPORTING for entire operation. When complete, the instance will contain only data from the imported file. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 922 def import_instance(name, import_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:import', ) command.request_representation = Google::Apis::RedisV1beta1::ImportInstanceRequest::Representation command.request_object = import_instance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backup_collection_backups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListBackupsResponse
Lists all backups owned by a backup collection.
341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 341 def list_project_location_backup_collection_backups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/backups', ) command.response_representation = Google::Apis::RedisV1beta1::ListBackupsResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListBackupsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backup_collections(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListBackupCollectionsResponse
Lists all backup collections owned by a consumer project in either the
specified location (region) or all locations. If location_id is specified as
- (wildcard), then all regions available to the project are queried, and the
results are aggregated.
197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 197 def list_project_location_backup_collections(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/backupCollections', ) command.response_representation = Google::Apis::RedisV1beta1::ListBackupCollectionsResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListBackupCollectionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_clusters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListClustersResponse
Lists all Redis clusters owned by a project in either the specified location (
region) or all locations. The location should have the following format: *
projects/project_id/locations/location_id`Iflocation_idis specified
as-` (wildcard), then all regions available to the project are queried, and
the results are aggregated.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 581 def list_project_location_clusters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/clusters', ) command.response_representation = Google::Apis::RedisV1beta1::ListClustersResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListClustersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListInstancesResponse
Lists all Redis instances owned by a project in either the specified location (
region) or all locations. The location should have the following format: *
projects/project_id/locations/location_id`Iflocation_idis specified
as-` (wildcard), then all regions available to the project are queried, and
the results are aggregated.
969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 969 def list_project_location_instances(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/instances', ) command.response_representation = Google::Apis::RedisV1beta1::ListInstancesResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1235 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::RedisV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::RedisV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::RedisV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Updates the metadata and configuration of a specific Redis cluster. Completed longrunning.Operation will contain the new cluster object in the response field. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 625 def patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::RedisV1beta1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Updates the metadata and configuration of a specific Redis instance. Completed longrunning.Operation will contain the new instance object in the response field. The returned operation is automatically deleted after a few hours, so there is no need to call DeleteOperation.
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1016 def patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::RedisV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reschedule_cluster_maintenance(name, reschedule_cluster_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Reschedules upcoming maintenance event.
662 663 664 665 666 667 668 669 670 671 672 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 662 def reschedule_cluster_maintenance(name, reschedule_cluster_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:rescheduleClusterMaintenance', ) command.request_representation = Google::Apis::RedisV1beta1::RescheduleClusterMaintenanceRequest::Representation command.request_object = reschedule_cluster_maintenance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reschedule_instance_maintenance(name, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Reschedule maintenance for a given instance in a given project and location.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1052 def reschedule_instance_maintenance(name, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:rescheduleMaintenance', ) command.request_representation = Google::Apis::RedisV1beta1::RescheduleMaintenanceRequest::Representation command.request_object = reschedule_maintenance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RedisV1beta1::Operation
Upgrades Redis instance to the newer Redis version specified in the request.
1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 |
# File 'lib/google/apis/redis_v1beta1/service.rb', line 1087 def upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:upgrade', ) command.request_representation = Google::Apis::RedisV1beta1::UpgradeInstanceRequest::Representation command.request_object = upgrade_instance_request_object command.response_representation = Google::Apis::RedisV1beta1::Operation::Representation command.response_class = Google::Apis::RedisV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |