Class: Google::Apis::RedisV1beta1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
A cluster instance.
Instance Attribute Summary collapse
-
#acl_policy ⇒ String
Optional.
-
#acl_policy_in_sync ⇒ Boolean
(also: #acl_policy_in_sync?)
Optional.
-
#acl_policy_info ⇒ Google::Apis::RedisV1beta1::AclPolicyInfo
Details of the applied ACL policy.
-
#allow_fewer_zones_deployment ⇒ Boolean
(also: #allow_fewer_zones_deployment?)
Optional.
-
#async_cluster_endpoints_deletion_enabled ⇒ Boolean
(also: #async_cluster_endpoints_deletion_enabled?)
Optional.
-
#authorization_mode ⇒ String
Optional.
-
#automated_backup_config ⇒ Google::Apis::RedisV1beta1::AutomatedBackupConfig
The automated backup config for a cluster.
-
#available_maintenance_versions ⇒ Array<String>
Output only.
-
#backup_collection ⇒ String
Optional.
-
#cluster_endpoints ⇒ Array<Google::Apis::RedisV1beta1::ClusterEndpoint>
Optional.
-
#create_time ⇒ String
Output only.
-
#cross_cluster_replication_config ⇒ Google::Apis::RedisV1beta1::CrossClusterReplicationConfig
Cross cluster replication config.
-
#deletion_protection_enabled ⇒ Boolean
(also: #deletion_protection_enabled?)
Optional.
-
#discovery_endpoints ⇒ Array<Google::Apis::RedisV1beta1::DiscoveryEndpoint>
Output only.
-
#effective_maintenance_version ⇒ String
Output only.
-
#encryption_info ⇒ Google::Apis::RedisV1beta1::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
-
#gcs_source ⇒ Google::Apis::RedisV1beta1::GcsBackupSource
Backups stored in Cloud Storage buckets.
-
#kms_key ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#maintenance_policy ⇒ Google::Apis::RedisV1beta1::ClusterMaintenancePolicy
Maintenance policy per cluster.
-
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ClusterMaintenanceSchedule
Upcoming maintenance schedule.
-
#maintenance_version ⇒ String
Optional.
-
#managed_backup_source ⇒ Google::Apis::RedisV1beta1::ManagedBackupSource
Backups that generated and managed by memorystore.
-
#name ⇒ String
Required.
-
#node_type ⇒ String
Optional.
-
#ondemand_maintenance ⇒ Boolean
(also: #ondemand_maintenance?)
Optional.
-
#persistence_config ⇒ Google::Apis::RedisV1beta1::ClusterPersistenceConfig
Configuration of the persistence functionality.
-
#precise_size_gb ⇒ Float
Output only.
-
#psc_configs ⇒ Array<Google::Apis::RedisV1beta1::PscConfig>
Optional.
-
#psc_connections ⇒ Array<Google::Apis::RedisV1beta1::PscConnection>
Output only.
-
#psc_service_attachments ⇒ Array<Google::Apis::RedisV1beta1::PscServiceAttachment>
Output only.
-
#redis_configs ⇒ Hash<String,String>
Optional.
-
#replica_count ⇒ Fixnum
Optional.
-
#rotate_server_certificate ⇒ Boolean
(also: #rotate_server_certificate?)
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Optional.
-
#server_ca_mode ⇒ String
Optional.
-
#server_ca_pool ⇒ String
Optional.
-
#shard_count ⇒ Fixnum
Optional.
-
#simulate_maintenance_event ⇒ Boolean
(also: #simulate_maintenance_event?)
Optional.
-
#size_gb ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#state_info ⇒ Google::Apis::RedisV1beta1::StateInfo
Represents additional information about the state of the cluster.
-
#transit_encryption_mode ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#zone_distribution_config ⇒ Google::Apis::RedisV1beta1::ZoneDistributionConfig
Zone distribution config for allocation of cluster resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
1114 1115 1116 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_policy ⇒ String
Optional. The ACL policy to be applied to the cluster.
Corresponds to the JSON property aclPolicy
854 855 856 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 854 def acl_policy @acl_policy end |
#acl_policy_in_sync ⇒ Boolean Also known as: acl_policy_in_sync?
Optional. Output only. Deprecated: Indicates whether the ACL rules applied to
the cluster are in sync.
Corresponds to the JSON property aclPolicyInSync
860 861 862 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 860 def acl_policy_in_sync @acl_policy_in_sync end |
#acl_policy_info ⇒ Google::Apis::RedisV1beta1::AclPolicyInfo
Details of the applied ACL policy.
Corresponds to the JSON property aclPolicyInfo
866 867 868 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 866 def acl_policy_info @acl_policy_info end |
#allow_fewer_zones_deployment ⇒ Boolean Also known as: allow_fewer_zones_deployment?
Optional. Immutable. Deprecated, do not use.
Corresponds to the JSON property allowFewerZonesDeployment
871 872 873 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 871 def allow_fewer_zones_deployment @allow_fewer_zones_deployment end |
#async_cluster_endpoints_deletion_enabled ⇒ Boolean Also known as: async_cluster_endpoints_deletion_enabled?
Optional. If true, cluster endpoints that are created and registered by
customers can be deleted asynchronously. That is, such a cluster endpoint can
be de-registered before the forwarding rules in the cluster endpoint are
deleted.
Corresponds to the JSON property asyncClusterEndpointsDeletionEnabled
880 881 882 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 880 def async_cluster_endpoints_deletion_enabled @async_cluster_endpoints_deletion_enabled end |
#authorization_mode ⇒ String
Optional. The authorization mode of the Redis cluster. If not provided, auth
feature is disabled for the cluster.
Corresponds to the JSON property authorizationMode
887 888 889 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 887 def @authorization_mode end |
#automated_backup_config ⇒ Google::Apis::RedisV1beta1::AutomatedBackupConfig
The automated backup config for a cluster.
Corresponds to the JSON property automatedBackupConfig
892 893 894 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 892 def automated_backup_config @automated_backup_config end |
#available_maintenance_versions ⇒ Array<String>
Output only. This field is used to determine the available maintenance
versions for the self service update.
Corresponds to the JSON property availableMaintenanceVersions
898 899 900 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 898 def available_maintenance_versions @available_maintenance_versions end |
#backup_collection ⇒ String
Optional. Output only. The backup collection full resource name. Example:
projects/project/locations/location/backupCollections/collection
Corresponds to the JSON property backupCollection
904 905 906 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 904 def backup_collection @backup_collection end |
#cluster_endpoints ⇒ Array<Google::Apis::RedisV1beta1::ClusterEndpoint>
Optional. A list of cluster endpoints.
Corresponds to the JSON property clusterEndpoints
909 910 911 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 909 def cluster_endpoints @cluster_endpoints end |
#create_time ⇒ String
Output only. The timestamp associated with the cluster creation request.
Corresponds to the JSON property createTime
914 915 916 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 914 def create_time @create_time end |
#cross_cluster_replication_config ⇒ Google::Apis::RedisV1beta1::CrossClusterReplicationConfig
Cross cluster replication config.
Corresponds to the JSON property crossClusterReplicationConfig
919 920 921 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 919 def cross_cluster_replication_config @cross_cluster_replication_config end |
#deletion_protection_enabled ⇒ Boolean Also known as: deletion_protection_enabled?
Optional. The delete operation will fail when the value is set to true.
Corresponds to the JSON property deletionProtectionEnabled
924 925 926 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 924 def deletion_protection_enabled @deletion_protection_enabled end |
#discovery_endpoints ⇒ Array<Google::Apis::RedisV1beta1::DiscoveryEndpoint>
Output only. Endpoints created on each given network, for Redis clients to
connect to the cluster. Currently only one discovery endpoint is supported.
Corresponds to the JSON property discoveryEndpoints
931 932 933 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 931 def discovery_endpoints @discovery_endpoints end |
#effective_maintenance_version ⇒ String
Output only. This field represents the actual maintenance version of the
cluster.
Corresponds to the JSON property effectiveMaintenanceVersion
937 938 939 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 937 def effective_maintenance_version @effective_maintenance_version end |
#encryption_info ⇒ Google::Apis::RedisV1beta1::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
Corresponds to the JSON property encryptionInfo
942 943 944 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 942 def encryption_info @encryption_info end |
#gcs_source ⇒ Google::Apis::RedisV1beta1::GcsBackupSource
Backups stored in Cloud Storage buckets. The Cloud Storage buckets need to be
the same region as the clusters.
Corresponds to the JSON property gcsSource
948 949 950 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 948 def gcs_source @gcs_source end |
#kms_key ⇒ String
Optional. The KMS key used to encrypt the at-rest data of the cluster.
Corresponds to the JSON property kmsKey
953 954 955 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 953 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Optional. Labels to represent user-provided metadata.
Corresponds to the JSON property labels
958 959 960 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 958 def labels @labels end |
#maintenance_policy ⇒ Google::Apis::RedisV1beta1::ClusterMaintenancePolicy
Maintenance policy per cluster.
Corresponds to the JSON property maintenancePolicy
963 964 965 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 963 def maintenance_policy @maintenance_policy end |
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ClusterMaintenanceSchedule
Upcoming maintenance schedule.
Corresponds to the JSON property maintenanceSchedule
968 969 970 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 968 def maintenance_schedule @maintenance_schedule end |
#maintenance_version ⇒ String
Optional. This field can be used to trigger self service update to indicate
the desired maintenance version. The input to this field can be determined by
the available_maintenance_versions field.
Corresponds to the JSON property maintenanceVersion
975 976 977 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 975 def maintenance_version @maintenance_version end |
#managed_backup_source ⇒ Google::Apis::RedisV1beta1::ManagedBackupSource
Backups that generated and managed by memorystore.
Corresponds to the JSON property managedBackupSource
980 981 982 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 980 def managed_backup_source @managed_backup_source end |
#name ⇒ String
Required. Identifier. Unique name of the resource in this scope including
project and location using the form: projects/project_id/locations/
location_id/clusters/cluster_id`
Corresponds to the JSON propertyname`
987 988 989 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 987 def name @name end |
#node_type ⇒ String
Optional. The type of a redis node in the cluster. NodeType determines the
underlying machine-type of a redis node.
Corresponds to the JSON property nodeType
993 994 995 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 993 def node_type @node_type end |
#ondemand_maintenance ⇒ Boolean Also known as: ondemand_maintenance?
Optional. Input only. Ondemand maintenance for the cluster. This field can be
used to trigger ondemand critical update on the cluster.
Corresponds to the JSON property ondemandMaintenance
999 1000 1001 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 999 def ondemand_maintenance @ondemand_maintenance end |
#persistence_config ⇒ Google::Apis::RedisV1beta1::ClusterPersistenceConfig
Configuration of the persistence functionality.
Corresponds to the JSON property persistenceConfig
1005 1006 1007 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1005 def persistence_config @persistence_config end |
#precise_size_gb ⇒ Float
Output only. Precise value of redis memory size in GB for the entire cluster.
Corresponds to the JSON property preciseSizeGb
1010 1011 1012 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1010 def precise_size_gb @precise_size_gb end |
#psc_configs ⇒ Array<Google::Apis::RedisV1beta1::PscConfig>
Optional. Each PscConfig configures the consumer network where IPs will be
designated to the cluster for client access through Private Service Connect
Automation. Currently, only one PscConfig is supported.
Corresponds to the JSON property pscConfigs
1017 1018 1019 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1017 def psc_configs @psc_configs end |
#psc_connections ⇒ Array<Google::Apis::RedisV1beta1::PscConnection>
Output only. The list of PSC connections that are auto-created through service
connectivity automation.
Corresponds to the JSON property pscConnections
1023 1024 1025 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1023 def psc_connections @psc_connections end |
#psc_service_attachments ⇒ Array<Google::Apis::RedisV1beta1::PscServiceAttachment>
Output only. Service attachment details to configure Psc connections
Corresponds to the JSON property pscServiceAttachments
1028 1029 1030 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1028 def @psc_service_attachments end |
#redis_configs ⇒ Hash<String,String>
Optional. Key/Value pairs of customer overrides for mutable Redis Configs
Corresponds to the JSON property redisConfigs
1033 1034 1035 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1033 def redis_configs @redis_configs end |
#replica_count ⇒ Fixnum
Optional. The number of replica nodes per shard.
Corresponds to the JSON property replicaCount
1038 1039 1040 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1038 def replica_count @replica_count end |
#rotate_server_certificate ⇒ Boolean Also known as: rotate_server_certificate?
Optional. Input only. Rotate the server certificates.
Corresponds to the JSON property rotateServerCertificate
1043 1044 1045 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1043 def rotate_server_certificate @rotate_server_certificate end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1049 1050 1051 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1049 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1055 1056 1057 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1055 def satisfies_pzs @satisfies_pzs end |
#server_ca_mode ⇒ String
Optional. Server CA mode for the cluster.
Corresponds to the JSON property serverCaMode
1061 1062 1063 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1061 def server_ca_mode @server_ca_mode end |
#server_ca_pool ⇒ String
Optional. Customer-managed CA pool for the cluster. Only applicable for BYOCA
i.e. if server_ca_mode is SERVER_CA_MODE_CUSTOMER_MANAGED_CAS_CA. Format: "
projects/project/locations/region/caPools/ca_pool".
Corresponds to the JSON property serverCaPool
1068 1069 1070 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1068 def server_ca_pool @server_ca_pool end |
#shard_count ⇒ Fixnum
Optional. Number of shards for the Redis cluster.
Corresponds to the JSON property shardCount
1073 1074 1075 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1073 def shard_count @shard_count end |
#simulate_maintenance_event ⇒ Boolean Also known as: simulate_maintenance_event?
Optional. Input only. Simulate a maintenance event.
Corresponds to the JSON property simulateMaintenanceEvent
1078 1079 1080 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1078 def simulate_maintenance_event @simulate_maintenance_event end |
#size_gb ⇒ Fixnum
Output only. Redis memory size in GB for the entire cluster rounded up to the
next integer.
Corresponds to the JSON property sizeGb
1085 1086 1087 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1085 def size_gb @size_gb end |
#state ⇒ String
Output only. The current state of this cluster. Can be CREATING, READY,
UPDATING, DELETING and SUSPENDED
Corresponds to the JSON property state
1091 1092 1093 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1091 def state @state end |
#state_info ⇒ Google::Apis::RedisV1beta1::StateInfo
Represents additional information about the state of the cluster.
Corresponds to the JSON property stateInfo
1096 1097 1098 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1096 def state_info @state_info end |
#transit_encryption_mode ⇒ String
Optional. The in-transit encryption for the Redis cluster. If not provided,
encryption is disabled for the cluster.
Corresponds to the JSON property transitEncryptionMode
1102 1103 1104 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1102 def transit_encryption_mode @transit_encryption_mode end |
#uid ⇒ String
Output only. System assigned, unique identifier for the cluster.
Corresponds to the JSON property uid
1107 1108 1109 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1107 def uid @uid end |
#zone_distribution_config ⇒ Google::Apis::RedisV1beta1::ZoneDistributionConfig
Zone distribution config for allocation of cluster resources.
Corresponds to the JSON property zoneDistributionConfig
1112 1113 1114 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1112 def zone_distribution_config @zone_distribution_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1119 def update!(**args) @acl_policy = args[:acl_policy] if args.key?(:acl_policy) @acl_policy_in_sync = args[:acl_policy_in_sync] if args.key?(:acl_policy_in_sync) @acl_policy_info = args[:acl_policy_info] if args.key?(:acl_policy_info) @allow_fewer_zones_deployment = args[:allow_fewer_zones_deployment] if args.key?(:allow_fewer_zones_deployment) @async_cluster_endpoints_deletion_enabled = args[:async_cluster_endpoints_deletion_enabled] if args.key?(:async_cluster_endpoints_deletion_enabled) @authorization_mode = args[:authorization_mode] if args.key?(:authorization_mode) @automated_backup_config = args[:automated_backup_config] if args.key?(:automated_backup_config) @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions) @backup_collection = args[:backup_collection] if args.key?(:backup_collection) @cluster_endpoints = args[:cluster_endpoints] if args.key?(:cluster_endpoints) @create_time = args[:create_time] if args.key?(:create_time) @cross_cluster_replication_config = args[:cross_cluster_replication_config] if args.key?(:cross_cluster_replication_config) @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled) @discovery_endpoints = args[:discovery_endpoints] if args.key?(:discovery_endpoints) @effective_maintenance_version = args[:effective_maintenance_version] if args.key?(:effective_maintenance_version) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @managed_backup_source = args[:managed_backup_source] if args.key?(:managed_backup_source) @name = args[:name] if args.key?(:name) @node_type = args[:node_type] if args.key?(:node_type) @ondemand_maintenance = args[:ondemand_maintenance] if args.key?(:ondemand_maintenance) @persistence_config = args[:persistence_config] if args.key?(:persistence_config) @precise_size_gb = args[:precise_size_gb] if args.key?(:precise_size_gb) @psc_configs = args[:psc_configs] if args.key?(:psc_configs) @psc_connections = args[:psc_connections] if args.key?(:psc_connections) @psc_service_attachments = args[:psc_service_attachments] if args.key?(:psc_service_attachments) @redis_configs = args[:redis_configs] if args.key?(:redis_configs) @replica_count = args[:replica_count] if args.key?(:replica_count) @rotate_server_certificate = args[:rotate_server_certificate] if args.key?(:rotate_server_certificate) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @server_ca_mode = args[:server_ca_mode] if args.key?(:server_ca_mode) @server_ca_pool = args[:server_ca_pool] if args.key?(:server_ca_pool) @shard_count = args[:shard_count] if args.key?(:shard_count) @simulate_maintenance_event = args[:simulate_maintenance_event] if args.key?(:simulate_maintenance_event) @size_gb = args[:size_gb] if args.key?(:size_gb) @state = args[:state] if args.key?(:state) @state_info = args[:state_info] if args.key?(:state_info) @transit_encryption_mode = args[:transit_encryption_mode] if args.key?(:transit_encryption_mode) @uid = args[:uid] if args.key?(:uid) @zone_distribution_config = args[:zone_distribution_config] if args.key?(:zone_distribution_config) end |