Class: Google::Apis::RedisV1beta1::ClusterEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

ClusterEndpoint consists of PSC connections that are created as a group in each VPC network for accessing the cluster. In each group, there shall be one connection for each service attachment in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterEndpoint

Returns a new instance of ClusterEndpoint.



1032
1033
1034
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsArray<Google::Apis::RedisV1beta1::ConnectionDetail>

Required. A group of PSC connections. They are created in the same VPC network, one for each service attachment in the cluster. Corresponds to the JSON property connections



1030
1031
1032
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1030

def connections
  @connections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1037
1038
1039
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1037

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
end