Class: Google::Apis::RedisV1beta1::ClusterEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ClusterEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
ClusterEndpoint consists of PSC connections that are created as a group in each VPC network for accessing the cluster. In each group, there shall be one connection for each service attachment in the cluster.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterEndpoint
constructor
A new instance of ClusterEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterEndpoint
Returns a new instance of ClusterEndpoint.
847 848 849 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connections ⇒ Array<Google::Apis::RedisV1beta1::ConnectionDetail>
Required. A group of PSC connections. They are created in the same VPC network,
one for each service attachment in the cluster.
Corresponds to the JSON property connections
845 846 847 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 845 def connections @connections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
852 853 854 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 852 def update!(**args) @connections = args[:connections] if args.key?(:connections) end |