Class: Google::Apis::RedisV1beta1::ClusterWeeklyMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ClusterWeeklyMaintenanceWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Time window specified for weekly operations.
Instance Attribute Summary collapse
-
#day ⇒ String
Optional.
-
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterWeeklyMaintenanceWindow
constructor
A new instance of ClusterWeeklyMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterWeeklyMaintenanceWindow
Returns a new instance of ClusterWeeklyMaintenanceWindow.
966 967 968 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Optional. Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
957 958 959 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 957 def day @day end |
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
964 965 966 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 964 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
971 972 973 974 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 971 def update!(**args) @day = args[:day] if args.key?(:day) @start_time = args[:start_time] if args.key?(:start_time) end |