Class: Google::Apis::RedisV1beta1::CrossClusterReplicationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::CrossClusterReplicationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Cross cluster replication config.
Instance Attribute Summary collapse
-
#cluster_role ⇒ String
Output only.
-
#membership ⇒ Google::Apis::RedisV1beta1::Membership
An output only view of all the member clusters participating in the cross cluster replication.
-
#primary_cluster ⇒ Google::Apis::RedisV1beta1::RemoteCluster
Details of the remote cluster associated with this cluster in a cross cluster replication setup.
-
#secondary_clusters ⇒ Array<Google::Apis::RedisV1beta1::RemoteCluster>
List of secondary clusters that are replicating from this primary cluster.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossClusterReplicationConfig
constructor
A new instance of CrossClusterReplicationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossClusterReplicationConfig
Returns a new instance of CrossClusterReplicationConfig.
1107 1108 1109 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_role ⇒ String
Output only. The role of the cluster in cross cluster replication.
Corresponds to the JSON property clusterRole
1082 1083 1084 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1082 def cluster_role @cluster_role end |
#membership ⇒ Google::Apis::RedisV1beta1::Membership
An output only view of all the member clusters participating in the cross
cluster replication.
Corresponds to the JSON property membership
1088 1089 1090 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1088 def membership @membership end |
#primary_cluster ⇒ Google::Apis::RedisV1beta1::RemoteCluster
Details of the remote cluster associated with this cluster in a cross cluster
replication setup.
Corresponds to the JSON property primaryCluster
1094 1095 1096 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1094 def primary_cluster @primary_cluster end |
#secondary_clusters ⇒ Array<Google::Apis::RedisV1beta1::RemoteCluster>
List of secondary clusters that are replicating from this primary cluster.
This field is only set for a primary cluster.
Corresponds to the JSON property secondaryClusters
1100 1101 1102 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1100 def secondary_clusters @secondary_clusters end |
#update_time ⇒ String
Output only. The last time cross cluster replication config was updated.
Corresponds to the JSON property updateTime
1105 1106 1107 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1105 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1112 def update!(**args) @cluster_role = args[:cluster_role] if args.key?(:cluster_role) @membership = args[:membership] if args.key?(:membership) @primary_cluster = args[:primary_cluster] if args.key?(:primary_cluster) @secondary_clusters = args[:secondary_clusters] if args.key?(:secondary_clusters) @update_time = args[:update_time] if args.key?(:update_time) end |