Class: Google::Apis::RedisV1beta1::DatabaseResourceHealthSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Common model for database resource health signal data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceHealthSignalData

Returns a new instance of DatabaseResourceHealthSignalData.



1326
1327
1328
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_metadataHash<String,Object>

Any other additional metadata Corresponds to the JSON property additionalMetadata

Returns:

  • (Hash<String,Object>)


1240
1241
1242
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1240

def 
  @additional_metadata
end

#complianceArray<Google::Apis::RedisV1beta1::Compliance>

Industry standards associated with this signal; if this signal is an issue, that could be a violation of the associated industry standard(s). For example, AUTO_BACKUP_DISABLED signal is associated with CIS GCP 1.1, CIS GCP 1.2, CIS GCP 1.3, NIST 800-53 and ISO-27001 compliance standards. If a database resource does not have automated backup enable, it will violate these following industry standards. Corresponds to the JSON property compliance



1250
1251
1252
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1250

def compliance
  @compliance
end

#descriptionString

Description associated with signal Corresponds to the JSON property description

Returns:

  • (String)


1255
1256
1257
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1255

def description
  @description
end

#event_timeString

Required. The last time at which the event described by this signal took place Corresponds to the JSON property eventTime

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1260

def event_time
  @event_time
end

#external_uriString

The external-uri of the signal, using which more information about this signal can be obtained. In GCP, this will take user to SCC page to get more details about signals. Corresponds to the JSON property externalUri

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1267

def external_uri
  @external_uri
end

#locationString

This is used to identify the location of the resource. Example: "us-central1" Corresponds to the JSON property location

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1272

def location
  @location
end

#nameString

Required. The name of the signal, ex: PUBLIC_SQL_INSTANCE, SQL_LOG_ERROR_VERBOSITY etc. Corresponds to the JSON property name

Returns:

  • (String)


1278
1279
1280
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1278

def name
  @name
end

#providerString

Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged Corresponds to the JSON property provider

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1283

def provider
  @provider
end

#resource_containerString

Closest parent container of this resource. In GCP, 'container' refers to a Cloud Resource Manager project. It must be resource name of a Cloud Resource Manager project with the format of "provider//", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1291

def resource_container
  @resource_container
end

#resource_nameString

Required. Database resource name associated with the signal. Resource name to follow CAIS resource_name format as noted here go/condor-common-datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


1297
1298
1299
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1297

def resource_name
  @resource_name
end

#signal_classString

Required. The class of the signal, such as if it's a THREAT or VULNERABILITY. Corresponds to the JSON property signalClass

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1302

def signal_class
  @signal_class
end

#signal_idString

Required. Unique identifier for the signal. This is an unique id which would be mainatined by partner to identify a signal. Corresponds to the JSON property signalId

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1308

def signal_id
  @signal_id
end

#signal_severityString

The severity of the signal, such as if it's a HIGH or LOW severity. Corresponds to the JSON property signalSeverity

Returns:

  • (String)


1313
1314
1315
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1313

def signal_severity
  @signal_severity
end

#signal_typeString

Required. Type of signal, for example, AVAILABLE_IN_MULTIPLE_ZONES, LOGGING_MOST_ERRORS, etc. Corresponds to the JSON property signalType

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1319

def signal_type
  @signal_type
end

#stateString

Corresponds to the JSON property state

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1324

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1331

def update!(**args)
  @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata)
  @compliance = args[:compliance] if args.key?(:compliance)
  @description = args[:description] if args.key?(:description)
  @event_time = args[:event_time] if args.key?(:event_time)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @signal_class = args[:signal_class] if args.key?(:signal_class)
  @signal_id = args[:signal_id] if args.key?(:signal_id)
  @signal_severity = args[:signal_severity] if args.key?(:signal_severity)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
  @state = args[:state] if args.key?(:state)
end