Class: Google::Apis::RedisV1beta1::DatabaseResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::DatabaseResourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Common model for database resource instance metadata. Next ID: 35
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata whichd does not support proto format.
-
#availability_configuration ⇒ Google::Apis::RedisV1beta1::AvailabilityConfiguration
Configuration for availability of database instance Corresponds to the JSON property
availabilityConfiguration. -
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#creation_time ⇒ String
The creation time of the resource, i.e.
-
#current_state ⇒ String
Current state of the instance.
-
#custom_metadata ⇒ Google::Apis::RedisV1beta1::CustomMetadataData
Any custom metadata associated with the resource.
-
#edition ⇒ String
Optional.
-
#entitlements ⇒ Array<Google::Apis::RedisV1beta1::Entitlement>
Entitlements associated with the resource Corresponds to the JSON property
entitlements. -
#expected_state ⇒ String
The state that the instance is expected to be in.
-
#gcbdr_configuration ⇒ Google::Apis::RedisV1beta1::GcbdrConfiguration
GCBDR Configuration for the resource.
-
#id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#instance_type ⇒ String
The type of the instance.
-
#internal_additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata which support proto format.
-
#ip_address ⇒ Google::Apis::RedisV1beta1::IpAddress
Used to send IP address information for a database resource.
-
#is_deletion_protection_enabled ⇒ Boolean
(also: #is_deletion_protection_enabled?)
Optional.
-
#location ⇒ String
The resource location.
-
#machine_configuration ⇒ Google::Apis::RedisV1beta1::MachineConfiguration
MachineConfiguration describes the configuration of a machine specific to Database Resource.
-
#maintenance_info ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
-
#modes ⇒ Array<String>
Optional.
-
#primary_resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#primary_resource_location ⇒ String
Primary resource location.
-
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
-
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource.
-
#resource_flags ⇒ Array<Google::Apis::RedisV1beta1::ResourceFlags>
Optional.
-
#resource_name ⇒ String
Required.
-
#suspension_reason ⇒ String
Optional.
-
#tags_set ⇒ Google::Apis::RedisV1beta1::Tags
Message type for storing tags.
-
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
-
#user_label_set ⇒ Google::Apis::RedisV1beta1::UserLabels
Message type for storing user labels.
-
#zone ⇒ String
The resource zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceMetadata
constructor
A new instance of DatabaseResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceMetadata
Returns a new instance of DatabaseResourceMetadata.
1945 1946 1947 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata whichd does not support proto format.
Corresponds to the JSON property additionalMetadata
1766 1767 1768 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1766 def @additional_metadata end |
#availability_configuration ⇒ Google::Apis::RedisV1beta1::AvailabilityConfiguration
Configuration for availability of database instance
Corresponds to the JSON property availabilityConfiguration
1771 1772 1773 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1771 def availability_configuration @availability_configuration end |
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
1776 1777 1778 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1776 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
1781 1782 1783 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1781 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
1787 1788 1789 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1787 def backupdr_configuration @backupdr_configuration end |
#creation_time ⇒ String
The creation time of the resource, i.e. the time when resource is created and
recorded in partner service.
Corresponds to the JSON property creationTime
1793 1794 1795 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1793 def creation_time @creation_time end |
#current_state ⇒ String
Current state of the instance.
Corresponds to the JSON property currentState
1798 1799 1800 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1798 def current_state @current_state end |
#custom_metadata ⇒ Google::Apis::RedisV1beta1::CustomMetadataData
Any custom metadata associated with the resource. e.g. A spanner instance can
have multiple databases with its own unique metadata. Information for these
individual databases can be captured in custom metadata data
Corresponds to the JSON property customMetadata
1805 1806 1807 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1805 def @custom_metadata end |
#edition ⇒ String
Optional. Edition represents whether the instance is ENTERPRISE or
ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to
identify the edition of the instance.
Corresponds to the JSON property edition
1812 1813 1814 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1812 def edition @edition end |
#entitlements ⇒ Array<Google::Apis::RedisV1beta1::Entitlement>
Entitlements associated with the resource
Corresponds to the JSON property entitlements
1817 1818 1819 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1817 def entitlements @entitlements end |
#expected_state ⇒ String
The state that the instance is expected to be in. For example, an instance
state can transition to UNHEALTHY due to wrong patch update, while the
expected state will remain at the HEALTHY.
Corresponds to the JSON property expectedState
1824 1825 1826 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1824 def expected_state @expected_state end |
#gcbdr_configuration ⇒ Google::Apis::RedisV1beta1::GcbdrConfiguration
GCBDR Configuration for the resource.
Corresponds to the JSON property gcbdrConfiguration
1829 1830 1831 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1829 def gcbdr_configuration @gcbdr_configuration end |
#id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property id
1834 1835 1836 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1834 def id @id end |
#instance_type ⇒ String
The type of the instance. Specified at creation time.
Corresponds to the JSON property instanceType
1839 1840 1841 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1839 def instance_type @instance_type end |
#internal_additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata which support proto format.
Corresponds to the JSON property internalAdditionalMetadata
1844 1845 1846 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1844 def @internal_additional_metadata end |
#ip_address ⇒ Google::Apis::RedisV1beta1::IpAddress
Used to send IP address information for a database resource.
Corresponds to the JSON property ipAddress
1849 1850 1851 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1849 def ip_address @ip_address end |
#is_deletion_protection_enabled ⇒ Boolean Also known as: is_deletion_protection_enabled?
Optional. Whether deletion protection is enabled for this resource.
Corresponds to the JSON property isDeletionProtectionEnabled
1854 1855 1856 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1854 def is_deletion_protection_enabled @is_deletion_protection_enabled end |
#location ⇒ String
The resource location. REQUIRED
Corresponds to the JSON property location
1860 1861 1862 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1860 def location @location end |
#machine_configuration ⇒ Google::Apis::RedisV1beta1::MachineConfiguration
MachineConfiguration describes the configuration of a machine specific to
Database Resource.
Corresponds to the JSON property machineConfiguration
1866 1867 1868 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1866 def machine_configuration @machine_configuration end |
#maintenance_info ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
Corresponds to the JSON property maintenanceInfo
1871 1872 1873 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1871 def maintenance_info @maintenance_info end |
#modes ⇒ Array<String>
Optional. The modes of the database resource.
Corresponds to the JSON property modes
1876 1877 1878 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1876 def modes @modes end |
#primary_resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property primaryResourceId
1881 1882 1883 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1881 def primary_resource_id @primary_resource_id end |
#primary_resource_location ⇒ String
Primary resource location. REQUIRED if the immediate parent exists when first
time resource is getting ingested, otherwise optional.
Corresponds to the JSON property primaryResourceLocation
1887 1888 1889 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1887 def primary_resource_location @primary_resource_location end |
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
Corresponds to the JSON property product
1892 1893 1894 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1892 def product @product end |
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource. It must be
resource name of a Cloud Resource Manager project with the format of "/", such
as "projects/123". For GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
1899 1900 1901 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1899 def resource_container @resource_container end |
#resource_flags ⇒ Array<Google::Apis::RedisV1beta1::ResourceFlags>
Optional. List of resource flags for the database resource.
Corresponds to the JSON property resourceFlags
1904 1905 1906 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1904 def resource_flags @resource_flags end |
#resource_name ⇒ String
Required. Different from DatabaseResourceId.unique_id, a resource name can be
reused over time. That is, after a resource named "ABC" is deleted, the name "
ABC" can be used to to create a new resource within the same source. Resource
name to follow CAIS resource_name format as noted here go/condor-common-
datamodel
Corresponds to the JSON property resourceName
1913 1914 1915 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1913 def resource_name @resource_name end |
#suspension_reason ⇒ String
Optional. Suspension reason for the resource.
Corresponds to the JSON property suspensionReason
1918 1919 1920 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1918 def suspension_reason @suspension_reason end |
#tags_set ⇒ Google::Apis::RedisV1beta1::Tags
Message type for storing tags. Tags provide a way to create annotations for
resources, and in some cases conditionally allow or deny policies based on
whether a resource has a specific tag.
Corresponds to the JSON property tagsSet
1925 1926 1927 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1925 def @tags_set end |
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
Corresponds to the JSON property updationTime
1930 1931 1932 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1930 def updation_time @updation_time end |
#user_label_set ⇒ Google::Apis::RedisV1beta1::UserLabels
Message type for storing user labels. User labels are used to tag App Engine
resources, allowing users to search for resources matching a set of labels and
to aggregate usage data by labels.
Corresponds to the JSON property userLabelSet
1937 1938 1939 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1937 def user_label_set @user_label_set end |
#zone ⇒ String
The resource zone. This is only applicable for zonal resources and will be
empty for regional and multi-regional resources.
Corresponds to the JSON property zone
1943 1944 1945 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1943 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1950 def update!(**args) @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata) @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @creation_time = args[:creation_time] if args.key?(:creation_time) @current_state = args[:current_state] if args.key?(:current_state) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @edition = args[:edition] if args.key?(:edition) @entitlements = args[:entitlements] if args.key?(:entitlements) @expected_state = args[:expected_state] if args.key?(:expected_state) @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration) @id = args[:id] if args.key?(:id) @instance_type = args[:instance_type] if args.key?(:instance_type) @internal_additional_metadata = args[:internal_additional_metadata] if args.key?(:internal_additional_metadata) @ip_address = args[:ip_address] if args.key?(:ip_address) @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled) @location = args[:location] if args.key?(:location) @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration) @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info) @modes = args[:modes] if args.key?(:modes) @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id) @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location) @product = args[:product] if args.key?(:product) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_flags = args[:resource_flags] if args.key?(:resource_flags) @resource_name = args[:resource_name] if args.key?(:resource_name) @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason) @tags_set = args[:tags_set] if args.key?(:tags_set) @updation_time = args[:updation_time] if args.key?(:updation_time) @user_label_set = args[:user_label_set] if args.key?(:user_label_set) @zone = args[:zone] if args.key?(:zone) end |