Class: Google::Apis::RedisV1beta1::DatabaseResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Common model for database resource instance metadata. Next ID: 30

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceMetadata

Returns a new instance of DatabaseResourceMetadata.



1557
1558
1559
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_configurationGoogle::Apis::RedisV1beta1::AvailabilityConfiguration

Configuration for availability of database instance Corresponds to the JSON property availabilityConfiguration



1403
1404
1405
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1403

def availability_configuration
  @availability_configuration
end

#backup_configurationGoogle::Apis::RedisV1beta1::BackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



1408
1409
1410
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1408

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::RedisV1beta1::BackupRun

A backup run. Corresponds to the JSON property backupRun



1413
1414
1415
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1413

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::RedisV1beta1::BackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



1419
1420
1421
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1419

def backupdr_configuration
  @backupdr_configuration
end

#creation_timeString

The creation time of the resource, i.e. the time when resource is created and recorded in partner service. Corresponds to the JSON property creationTime

Returns:

  • (String)


1425
1426
1427
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1425

def creation_time
  @creation_time
end

#current_stateString

Current state of the instance. Corresponds to the JSON property currentState

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1430

def current_state
  @current_state
end

#custom_metadataGoogle::Apis::RedisV1beta1::CustomMetadataData

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data Corresponds to the JSON property customMetadata



1437
1438
1439
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1437

def 
  @custom_metadata
end

#editionString

Optional. Edition represents whether the instance is ENTERPRISE or ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to identify the edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1444

def edition
  @edition
end

#entitlementsArray<Google::Apis::RedisV1beta1::Entitlement>

Entitlements associated with the resource Corresponds to the JSON property entitlements



1449
1450
1451
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1449

def entitlements
  @entitlements
end

#expected_stateString

The state that the instance is expected to be in. For example, an instance state can transition to UNHEALTHY due to wrong patch update, while the expected state will remain at the HEALTHY. Corresponds to the JSON property expectedState

Returns:

  • (String)


1456
1457
1458
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1456

def expected_state
  @expected_state
end

#gcbdr_configurationGoogle::Apis::RedisV1beta1::GcbdrConfiguration

GCBDR Configuration for the resource. Corresponds to the JSON property gcbdrConfiguration



1461
1462
1463
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1461

def gcbdr_configuration
  @gcbdr_configuration
end

#idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property id



1466
1467
1468
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1466

def id
  @id
end

#instance_typeString

The type of the instance. Specified at creation time. Corresponds to the JSON property instanceType

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1471

def instance_type
  @instance_type
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Optional. Whether deletion protection is enabled for this resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


1476
1477
1478
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1476

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#locationString

The resource location. REQUIRED Corresponds to the JSON property location

Returns:

  • (String)


1482
1483
1484
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1482

def location
  @location
end

#machine_configurationGoogle::Apis::RedisV1beta1::MachineConfiguration

MachineConfiguration describes the configuration of a machine specific to Database Resource. Corresponds to the JSON property machineConfiguration



1488
1489
1490
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1488

def machine_configuration
  @machine_configuration
end

#maintenance_infoGoogle::Apis::RedisV1beta1::ResourceMaintenanceInfo

MaintenanceInfo to capture the maintenance details of database resource. Corresponds to the JSON property maintenanceInfo



1493
1494
1495
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1493

def maintenance_info
  @maintenance_info
end

#primary_resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property primaryResourceId



1498
1499
1500
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1498

def primary_resource_id
  @primary_resource_id
end

#primary_resource_locationString

Primary resource location. REQUIRED if the immediate parent exists when first time resource is getting ingested, otherwise optional. Corresponds to the JSON property primaryResourceLocation

Returns:

  • (String)


1504
1505
1506
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1504

def primary_resource_location
  @primary_resource_location
end

#productGoogle::Apis::RedisV1beta1::Product

Product specification for Condor resources. Corresponds to the JSON property product



1509
1510
1511
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1509

def product
  @product
end

#resource_containerString

Closest parent Cloud Resource Manager container of this resource. It must be resource name of a Cloud Resource Manager project with the format of "/", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1516
1517
1518
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1516

def resource_container
  @resource_container
end

#resource_nameString

Required. Different from DatabaseResourceId.unique_id, a resource name can be reused over time. That is, after a resource named "ABC" is deleted, the name " ABC" can be used to to create a new resource within the same source. Resource name to follow CAIS resource_name format as noted here go/condor-common- datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


1525
1526
1527
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1525

def resource_name
  @resource_name
end

#suspension_reasonString

Optional. Suspension reason for the resource. Corresponds to the JSON property suspensionReason

Returns:

  • (String)


1530
1531
1532
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1530

def suspension_reason
  @suspension_reason
end

#tags_setGoogle::Apis::RedisV1beta1::Tags

Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag. Corresponds to the JSON property tagsSet



1537
1538
1539
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1537

def tags_set
  @tags_set
end

#updation_timeString

The time at which the resource was updated and recorded at partner service. Corresponds to the JSON property updationTime

Returns:

  • (String)


1542
1543
1544
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1542

def updation_time
  @updation_time
end

#user_label_setGoogle::Apis::RedisV1beta1::UserLabels

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels. Corresponds to the JSON property userLabelSet



1549
1550
1551
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1549

def user_label_set
  @user_label_set
end

#zoneString

The resource zone. This is only applicable for zonal resources and will be empty for regional and multi-regional resources. Corresponds to the JSON property zone

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1555

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1562

def update!(**args)
  @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @current_state = args[:current_state] if args.key?(:current_state)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @edition = args[:edition] if args.key?(:edition)
  @entitlements = args[:entitlements] if args.key?(:entitlements)
  @expected_state = args[:expected_state] if args.key?(:expected_state)
  @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration)
  @id = args[:id] if args.key?(:id)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @location = args[:location] if args.key?(:location)
  @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration)
  @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info)
  @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id)
  @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location)
  @product = args[:product] if args.key?(:product)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @tags_set = args[:tags_set] if args.key?(:tags_set)
  @updation_time = args[:updation_time] if args.key?(:updation_time)
  @user_label_set = args[:user_label_set] if args.key?(:user_label_set)
  @zone = args[:zone] if args.key?(:zone)
end