Class: Google::Apis::RedisV1beta1::DatabaseResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::DatabaseResourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Common model for database resource instance metadata. Next ID: 30
Instance Attribute Summary collapse
-
#availability_configuration ⇒ Google::Apis::RedisV1beta1::AvailabilityConfiguration
Configuration for availability of database instance Corresponds to the JSON property
availabilityConfiguration. -
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#creation_time ⇒ String
The creation time of the resource, i.e.
-
#current_state ⇒ String
Current state of the instance.
-
#custom_metadata ⇒ Google::Apis::RedisV1beta1::CustomMetadataData
Any custom metadata associated with the resource.
-
#edition ⇒ String
Optional.
-
#entitlements ⇒ Array<Google::Apis::RedisV1beta1::Entitlement>
Entitlements associated with the resource Corresponds to the JSON property
entitlements. -
#expected_state ⇒ String
The state that the instance is expected to be in.
-
#gcbdr_configuration ⇒ Google::Apis::RedisV1beta1::GcbdrConfiguration
GCBDR Configuration for the resource.
-
#id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#instance_type ⇒ String
The type of the instance.
-
#is_deletion_protection_enabled ⇒ Boolean
(also: #is_deletion_protection_enabled?)
Optional.
-
#location ⇒ String
The resource location.
-
#machine_configuration ⇒ Google::Apis::RedisV1beta1::MachineConfiguration
MachineConfiguration describes the configuration of a machine specific to Database Resource.
-
#maintenance_info ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
-
#primary_resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#primary_resource_location ⇒ String
Primary resource location.
-
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
-
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource.
-
#resource_name ⇒ String
Required.
-
#suspension_reason ⇒ String
Optional.
-
#tags_set ⇒ Google::Apis::RedisV1beta1::Tags
Message type for storing tags.
-
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
-
#user_label_set ⇒ Google::Apis::RedisV1beta1::UserLabels
Message type for storing user labels.
-
#zone ⇒ String
The resource zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceMetadata
constructor
A new instance of DatabaseResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceMetadata
Returns a new instance of DatabaseResourceMetadata.
1557 1558 1559 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability_configuration ⇒ Google::Apis::RedisV1beta1::AvailabilityConfiguration
Configuration for availability of database instance
Corresponds to the JSON property availabilityConfiguration
1403 1404 1405 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1403 def availability_configuration @availability_configuration end |
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
1408 1409 1410 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1408 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
1413 1414 1415 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1413 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::RedisV1beta1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
1419 1420 1421 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1419 def backupdr_configuration @backupdr_configuration end |
#creation_time ⇒ String
The creation time of the resource, i.e. the time when resource is created and
recorded in partner service.
Corresponds to the JSON property creationTime
1425 1426 1427 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1425 def creation_time @creation_time end |
#current_state ⇒ String
Current state of the instance.
Corresponds to the JSON property currentState
1430 1431 1432 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1430 def current_state @current_state end |
#custom_metadata ⇒ Google::Apis::RedisV1beta1::CustomMetadataData
Any custom metadata associated with the resource. e.g. A spanner instance can
have multiple databases with its own unique metadata. Information for these
individual databases can be captured in custom metadata data
Corresponds to the JSON property customMetadata
1437 1438 1439 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1437 def @custom_metadata end |
#edition ⇒ String
Optional. Edition represents whether the instance is ENTERPRISE or
ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to
identify the edition of the instance.
Corresponds to the JSON property edition
1444 1445 1446 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1444 def edition @edition end |
#entitlements ⇒ Array<Google::Apis::RedisV1beta1::Entitlement>
Entitlements associated with the resource
Corresponds to the JSON property entitlements
1449 1450 1451 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1449 def entitlements @entitlements end |
#expected_state ⇒ String
The state that the instance is expected to be in. For example, an instance
state can transition to UNHEALTHY due to wrong patch update, while the
expected state will remain at the HEALTHY.
Corresponds to the JSON property expectedState
1456 1457 1458 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1456 def expected_state @expected_state end |
#gcbdr_configuration ⇒ Google::Apis::RedisV1beta1::GcbdrConfiguration
GCBDR Configuration for the resource.
Corresponds to the JSON property gcbdrConfiguration
1461 1462 1463 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1461 def gcbdr_configuration @gcbdr_configuration end |
#id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property id
1466 1467 1468 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1466 def id @id end |
#instance_type ⇒ String
The type of the instance. Specified at creation time.
Corresponds to the JSON property instanceType
1471 1472 1473 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1471 def instance_type @instance_type end |
#is_deletion_protection_enabled ⇒ Boolean Also known as: is_deletion_protection_enabled?
Optional. Whether deletion protection is enabled for this resource.
Corresponds to the JSON property isDeletionProtectionEnabled
1476 1477 1478 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1476 def is_deletion_protection_enabled @is_deletion_protection_enabled end |
#location ⇒ String
The resource location. REQUIRED
Corresponds to the JSON property location
1482 1483 1484 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1482 def location @location end |
#machine_configuration ⇒ Google::Apis::RedisV1beta1::MachineConfiguration
MachineConfiguration describes the configuration of a machine specific to
Database Resource.
Corresponds to the JSON property machineConfiguration
1488 1489 1490 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1488 def machine_configuration @machine_configuration end |
#maintenance_info ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
Corresponds to the JSON property maintenanceInfo
1493 1494 1495 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1493 def maintenance_info @maintenance_info end |
#primary_resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property primaryResourceId
1498 1499 1500 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1498 def primary_resource_id @primary_resource_id end |
#primary_resource_location ⇒ String
Primary resource location. REQUIRED if the immediate parent exists when first
time resource is getting ingested, otherwise optional.
Corresponds to the JSON property primaryResourceLocation
1504 1505 1506 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1504 def primary_resource_location @primary_resource_location end |
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
Corresponds to the JSON property product
1509 1510 1511 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1509 def product @product end |
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource. It must be
resource name of a Cloud Resource Manager project with the format of "/", such
as "projects/123". For GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
1516 1517 1518 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1516 def resource_container @resource_container end |
#resource_name ⇒ String
Required. Different from DatabaseResourceId.unique_id, a resource name can be
reused over time. That is, after a resource named "ABC" is deleted, the name "
ABC" can be used to to create a new resource within the same source. Resource
name to follow CAIS resource_name format as noted here go/condor-common-
datamodel
Corresponds to the JSON property resourceName
1525 1526 1527 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1525 def resource_name @resource_name end |
#suspension_reason ⇒ String
Optional. Suspension reason for the resource.
Corresponds to the JSON property suspensionReason
1530 1531 1532 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1530 def suspension_reason @suspension_reason end |
#tags_set ⇒ Google::Apis::RedisV1beta1::Tags
Message type for storing tags. Tags provide a way to create annotations for
resources, and in some cases conditionally allow or deny policies based on
whether a resource has a specific tag.
Corresponds to the JSON property tagsSet
1537 1538 1539 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1537 def @tags_set end |
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
Corresponds to the JSON property updationTime
1542 1543 1544 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1542 def updation_time @updation_time end |
#user_label_set ⇒ Google::Apis::RedisV1beta1::UserLabels
Message type for storing user labels. User labels are used to tag App Engine
resources, allowing users to search for resources matching a set of labels and
to aggregate usage data by labels.
Corresponds to the JSON property userLabelSet
1549 1550 1551 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1549 def user_label_set @user_label_set end |
#zone ⇒ String
The resource zone. This is only applicable for zonal resources and will be
empty for regional and multi-regional resources.
Corresponds to the JSON property zone
1555 1556 1557 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1555 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1562 def update!(**args) @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @creation_time = args[:creation_time] if args.key?(:creation_time) @current_state = args[:current_state] if args.key?(:current_state) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @edition = args[:edition] if args.key?(:edition) @entitlements = args[:entitlements] if args.key?(:entitlements) @expected_state = args[:expected_state] if args.key?(:expected_state) @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration) @id = args[:id] if args.key?(:id) @instance_type = args[:instance_type] if args.key?(:instance_type) @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled) @location = args[:location] if args.key?(:location) @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration) @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info) @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id) @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location) @product = args[:product] if args.key?(:product) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_name = args[:resource_name] if args.key?(:resource_name) @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason) @tags_set = args[:tags_set] if args.key?(:tags_set) @updation_time = args[:updation_time] if args.key?(:updation_time) @user_label_set = args[:user_label_set] if args.key?(:user_label_set) @zone = args[:zone] if args.key?(:zone) end |