Class: Google::Apis::RedisV1beta1::DatabaseResourceSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceSignalData

Returns a new instance of DatabaseResourceSignalData.



1934
1935
1936
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_runGoogle::Apis::RedisV1beta1::BackupRun

A backup run. Corresponds to the JSON property backupRun



1890
1891
1892
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1890

def backup_run
  @backup_run
end

#full_resource_nameString

Required. Full Resource name of the source resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


1895
1896
1897
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1895

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time signal was refreshed Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


1900
1901
1902
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1900

def last_refresh_time
  @last_refresh_time
end

#locationString

Required. Resource location. Corresponds to the JSON property location

Returns:

  • (String)


1905
1906
1907
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1905

def location
  @location
end

#resource_idGoogle::Apis::RedisV1beta1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



1910
1911
1912
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1910

def resource_id
  @resource_id
end

#signal_bool_valueBoolean Also known as: signal_bool_value?

Deprecated: Use signal_metadata_list instead. Corresponds to the JSON property signalBoolValue

Returns:

  • (Boolean)


1915
1916
1917
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1915

def signal_bool_value
  @signal_bool_value
end

#signal_metadata_listArray<Google::Apis::RedisV1beta1::SignalMetadata>

This will support array of OneOf signal metadata information for a given signal type. Corresponds to the JSON property signalMetadataList



1922
1923
1924
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1922

def 
  @signal_metadata_list
end

#signal_stateString

Required. Output only. Signal state of the signal Corresponds to the JSON property signalState

Returns:

  • (String)


1927
1928
1929
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1927

def signal_state
  @signal_state
end

#signal_typeString

Required. Signal type of the signal Corresponds to the JSON property signalType

Returns:

  • (String)


1932
1933
1934
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1932

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1939

def update!(**args)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @location = args[:location] if args.key?(:location)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value)
  @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list)
  @signal_state = args[:signal_state] if args.key?(:signal_state)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end