Class: Google::Apis::RedisV1beta1::DiscoveryEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::DiscoveryEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Endpoints on each network, for Redis clients to connect to the cluster.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#port ⇒ Fixnum
Output only.
-
#psc_config ⇒ Google::Apis::RedisV1beta1::PscConfig
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryEndpoint
constructor
A new instance of DiscoveryEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryEndpoint
Returns a new instance of DiscoveryEndpoint.
2192 2193 2194 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. Address of the exposed Redis endpoint used by clients to connect
to the service. The address could be either IP or hostname.
Corresponds to the JSON property address
2179 2180 2181 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2179 def address @address end |
#port ⇒ Fixnum
Output only. The port number of the exposed Redis endpoint.
Corresponds to the JSON property port
2184 2185 2186 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2184 def port @port end |
#psc_config ⇒ Google::Apis::RedisV1beta1::PscConfig
Output only. Customer configuration for where the endpoint is created and
accessed from.
Corresponds to the JSON property pscConfig
2190 2191 2192 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2190 def psc_config @psc_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2197 2198 2199 2200 2201 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2197 def update!(**args) @address = args[:address] if args.key?(:address) @port = args[:port] if args.key?(:port) @psc_config = args[:psc_config] if args.key?(:psc_config) end |