Class: Google::Apis::RedisV1beta1::DiscoveryEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::DiscoveryEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Endpoints on each network, for Redis clients to connect to the cluster.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#port ⇒ Fixnum
Output only.
-
#psc_config ⇒ Google::Apis::RedisV1beta1::PscConfig
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryEndpoint
constructor
A new instance of DiscoveryEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryEndpoint
Returns a new instance of DiscoveryEndpoint.
2014 2015 2016 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. Address of the exposed Redis endpoint used by clients to connect
to the service. The address could be either IP or hostname.
Corresponds to the JSON property address
2001 2002 2003 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2001 def address @address end |
#port ⇒ Fixnum
Output only. The port number of the exposed Redis endpoint.
Corresponds to the JSON property port
2006 2007 2008 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2006 def port @port end |
#psc_config ⇒ Google::Apis::RedisV1beta1::PscConfig
Output only. Customer configuration for where the endpoint is created and
accessed from.
Corresponds to the JSON property pscConfig
2012 2013 2014 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2012 def psc_config @psc_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2019 2020 2021 2022 2023 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2019 def update!(**args) @address = args[:address] if args.key?(:address) @port = args[:port] if args.key?(:port) @psc_config = args[:psc_config] if args.key?(:psc_config) end |