Class: Google::Apis::RedisV1beta1::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::EncryptionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
EncryptionInfo describes the encryption information of a cluster or a backup.
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
Output only.
-
#kms_key_primary_state ⇒ String
Output only.
-
#kms_key_versions ⇒ Array<String>
Output only.
-
#last_update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionInfo
constructor
A new instance of EncryptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionInfo
Returns a new instance of EncryptionInfo.
2245 2246 2247 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_type ⇒ String
Output only. Type of encryption.
Corresponds to the JSON property encryptionType
2227 2228 2229 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2227 def encryption_type @encryption_type end |
#kms_key_primary_state ⇒ String
Output only. The state of the primary version of the KMS key perceived by the
system. This field is not populated in backups.
Corresponds to the JSON property kmsKeyPrimaryState
2233 2234 2235 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2233 def kms_key_primary_state @kms_key_primary_state end |
#kms_key_versions ⇒ Array<String>
Output only. KMS key versions that are being used to protect the data at-rest.
Corresponds to the JSON property kmsKeyVersions
2238 2239 2240 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2238 def kms_key_versions @kms_key_versions end |
#last_update_time ⇒ String
Output only. The most recent time when the encryption info was updated.
Corresponds to the JSON property lastUpdateTime
2243 2244 2245 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2243 def last_update_time @last_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2250 2251 2252 2253 2254 2255 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2250 def update!(**args) @encryption_type = args[:encryption_type] if args.key?(:encryption_type) @kms_key_primary_state = args[:kms_key_primary_state] if args.key?(:kms_key_primary_state) @kms_key_versions = args[:kms_key_versions] if args.key?(:kms_key_versions) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) end |