Class: Google::Apis::RedisV1beta1::EncryptionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

EncryptionInfo describes the encryption information of a cluster or a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionInfo

Returns a new instance of EncryptionInfo.



1860
1861
1862
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_typeString

Output only. Type of encryption. Corresponds to the JSON property encryptionType

Returns:

  • (String)


1842
1843
1844
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1842

def encryption_type
  @encryption_type
end

#kms_key_primary_stateString

Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups. Corresponds to the JSON property kmsKeyPrimaryState

Returns:

  • (String)


1848
1849
1850
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1848

def kms_key_primary_state
  @kms_key_primary_state
end

#kms_key_versionsArray<String>

Output only. KMS key versions that are being used to protect the data at-rest. Corresponds to the JSON property kmsKeyVersions

Returns:

  • (Array<String>)


1853
1854
1855
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1853

def kms_key_versions
  @kms_key_versions
end

#last_update_timeString

Output only. The most recent time when the encryption info was updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1858

def last_update_time
  @last_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1865
1866
1867
1868
1869
1870
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1865

def update!(**args)
  @encryption_type = args[:encryption_type] if args.key?(:encryption_type)
  @kms_key_primary_state = args[:kms_key_primary_state] if args.key?(:kms_key_primary_state)
  @kms_key_versions = args[:kms_key_versions] if args.key?(:kms_key_versions)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
end