Class: Google::Apis::RedisV1beta1::EncryptionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

EncryptionInfo describes the encryption information of a cluster or a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionInfo

Returns a new instance of EncryptionInfo.



1833
1834
1835
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_typeString

Output only. Type of encryption. Corresponds to the JSON property encryptionType

Returns:

  • (String)


1815
1816
1817
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1815

def encryption_type
  @encryption_type
end

#kms_key_primary_stateString

Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups. Corresponds to the JSON property kmsKeyPrimaryState

Returns:

  • (String)


1821
1822
1823
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1821

def kms_key_primary_state
  @kms_key_primary_state
end

#kms_key_versionsArray<String>

Output only. KMS key versions that are being used to protect the data at-rest. Corresponds to the JSON property kmsKeyVersions

Returns:

  • (Array<String>)


1826
1827
1828
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1826

def kms_key_versions
  @kms_key_versions
end

#last_update_timeString

Output only. The most recent time when the encryption info was updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


1831
1832
1833
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1831

def last_update_time
  @last_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1838
1839
1840
1841
1842
1843
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1838

def update!(**args)
  @encryption_type = args[:encryption_type] if args.key?(:encryption_type)
  @kms_key_primary_state = args[:kms_key_primary_state] if args.key?(:kms_key_primary_state)
  @kms_key_versions = args[:kms_key_versions] if args.key?(:kms_key_versions)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
end