Class: Google::Apis::RedisV1beta1::FixedFrequencySchedule
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::FixedFrequencySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
This schedule allows the backup to be triggered at a fixed frequency ( currently only daily is supported).
Instance Attribute Summary collapse
-
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FixedFrequencySchedule
constructor
A new instance of FixedFrequencySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FixedFrequencySchedule
Returns a new instance of FixedFrequencySchedule.
1942 1943 1944 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1940 1941 1942 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1940 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1947 1948 1949 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 1947 def update!(**args) @start_time = args[:start_time] if args.key?(:start_time) end |