Class: Google::Apis::RedisV1beta1::InternalResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::InternalResourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration settings. Similarly bigtable can have multiple clusters within same bigtable instance.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
-
#is_deletion_protection_enabled ⇒ Boolean
(also: #is_deletion_protection_enabled?)
Whether deletion protection is enabled for this internal resource.
-
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
-
#resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#resource_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InternalResourceMetadata
constructor
A new instance of InternalResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InternalResourceMetadata
Returns a new instance of InternalResourceMetadata.
2760 2761 2762 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::RedisV1beta1::BackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
2731 2732 2733 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2731 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::RedisV1beta1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
2736 2737 2738 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2736 def backup_run @backup_run end |
#is_deletion_protection_enabled ⇒ Boolean Also known as: is_deletion_protection_enabled?
Whether deletion protection is enabled for this internal resource.
Corresponds to the JSON property isDeletionProtectionEnabled
2741 2742 2743 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2741 def is_deletion_protection_enabled @is_deletion_protection_enabled end |
#product ⇒ Google::Apis::RedisV1beta1::Product
Product specification for Condor resources.
Corresponds to the JSON property product
2747 2748 2749 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2747 def product @product end |
#resource_id ⇒ Google::Apis::RedisV1beta1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
2752 2753 2754 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2752 def resource_id @resource_id end |
#resource_name ⇒ String
Required. internal resource name for spanner this will be database name e.g."
spanner.googleapis.com/projects/123/abc/instances/inst1/databases/db1"
Corresponds to the JSON property resourceName
2758 2759 2760 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2758 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2765 2766 2767 2768 2769 2770 2771 2772 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2765 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled) @product = args[:product] if args.key?(:product) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |