Class: Google::Apis::RedisV1beta1::ListAclPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Response for ListAclPolicies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAclPoliciesResponse

Returns a new instance of ListAclPoliciesResponse.



2780
2781
2782
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_policiesArray<Google::Apis::RedisV1beta1::AclPolicy>

A list of ACL policies in the project in the specified location, or across all locations. If the location_id in the parent field of the request is "-", all regions available to the project are queried, and the results aggregated. Corresponds to the JSON property aclPolicies



2767
2768
2769
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2767

def acl_policies
  @acl_policies
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2773
2774
2775
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2773

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2778
2779
2780
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2778

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2785
2786
2787
2788
2789
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2785

def update!(**args)
  @acl_policies = args[:acl_policies] if args.key?(:acl_policies)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end