Class: Google::Apis::RedisV1beta1::ListAclPolicyRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ListAclPolicyRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Response for ListAclPolicyRevisions.
Instance Attribute Summary collapse
-
#acl_policy_revisions ⇒ Array<Google::Apis::RedisV1beta1::AclPolicyRevision>
A list of ACL policy revisions.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAclPolicyRevisionsResponse
constructor
A new instance of ListAclPolicyRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAclPolicyRevisionsResponse
Returns a new instance of ListAclPolicyRevisionsResponse.
3036 3037 3038 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_policy_revisions ⇒ Array<Google::Apis::RedisV1beta1::AclPolicyRevision>
A list of ACL policy revisions.
Corresponds to the JSON property aclPolicyRevisions
3023 3024 3025 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3023 def acl_policy_revisions @acl_policy_revisions end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
3029 3030 3031 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3029 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
3034 3035 3036 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3034 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3041 3042 3043 3044 3045 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3041 def update!(**args) @acl_policy_revisions = args[:acl_policy_revisions] if args.key?(:acl_policy_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |