Class: Google::Apis::RedisV1beta1::ListAuthTokensResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ListAuthTokensResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Response message for ListAuthTokens.
Instance Attribute Summary collapse
-
#auth_tokens ⇒ Array<Google::Apis::RedisV1beta1::AuthToken>
A list of auth tokens in the project.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAuthTokensResponse
constructor
A new instance of ListAuthTokensResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAuthTokensResponse
Returns a new instance of ListAuthTokensResponse.
2812 2813 2814 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_tokens ⇒ Array<Google::Apis::RedisV1beta1::AuthToken>
A list of auth tokens in the project.
Corresponds to the JSON property authTokens
2799 2800 2801 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2799 def auth_tokens @auth_tokens end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
2805 2806 2807 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2805 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Auth tokens that could not be reached.
Corresponds to the JSON property unreachable
2810 2811 2812 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2810 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2817 2818 2819 2820 2821 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2817 def update!(**args) @auth_tokens = args[:auth_tokens] if args.key?(:auth_tokens) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |