Class: Google::Apis::RedisV1beta1::ListTokenAuthUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ListTokenAuthUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Response message for ListTokenAuthUsers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#token_auth_users ⇒ Array<Google::Apis::RedisV1beta1::TokenAuthUser>
A list of token auth users in the project.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTokenAuthUsersResponse
constructor
A new instance of ListTokenAuthUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTokenAuthUsersResponse
Returns a new instance of ListTokenAuthUsersResponse.
3052 3053 3054 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
3040 3041 3042 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3040 def next_page_token @next_page_token end |
#token_auth_users ⇒ Array<Google::Apis::RedisV1beta1::TokenAuthUser>
A list of token auth users in the project.
Corresponds to the JSON property tokenAuthUsers
3045 3046 3047 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3045 def token_auth_users @token_auth_users end |
#unreachable ⇒ Array<String>
Unordered list. Token auth users that could not be reached.
Corresponds to the JSON property unreachable
3050 3051 3052 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3050 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3057 3058 3059 3060 3061 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3057 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @token_auth_users = args[:token_auth_users] if args.key?(:token_auth_users) @unreachable = args[:unreachable] if args.key?(:unreachable) end |