Class: Google::Apis::RedisV1beta1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



3144
3145
3146
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


3117
3118
3119
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3117

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3123
3124
3125
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3123

def labels
  @labels
end

#location_idString

Resource ID for the region. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


3128
3129
3130
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3128

def location_id
  @location_id
end

#metadataHash<String,Object>

Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by Compute Engine. These keys can be specified in location_id or alternative_location_id fields when creating a Redis instance. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


3136
3137
3138
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3136

def 
  @metadata
end

#nameString

Full resource name for the region. For example: "projects/example-project/ locations/us-east1". Corresponds to the JSON property name

Returns:

  • (String)


3142
3143
3144
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3142

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3149
3150
3151
3152
3153
3154
3155
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3149

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end