Class: Google::Apis::RedisV1beta1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



2811
2812
2813
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


2784
2785
2786
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2784

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2790
2791
2792
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2790

def labels
  @labels
end

#location_idString

Resource ID for the region. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2795

def location_id
  @location_id
end

#metadataHash<String,Object>

Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by Compute Engine. These keys can be specified in location_id or alternative_location_id fields when creating a Redis instance. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2803
2804
2805
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2803

def 
  @metadata
end

#nameString

Full resource name for the region. For example: "projects/example-project/ locations/us-east1". Corresponds to the JSON property name

Returns:

  • (String)


2809
2810
2811
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2809

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2816
2817
2818
2819
2820
2821
2822
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 2816

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end