Class: Google::Apis::RedisV1beta1::MaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::MaintenanceSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Upcoming maintenance schedule. If no maintenance is scheduled, fields are not populated.
Instance Attribute Summary collapse
-
#can_reschedule ⇒ Boolean
(also: #can_reschedule?)
If the scheduled maintenance can be rescheduled, default is true.
-
#end_time ⇒ String
Output only.
-
#schedule_deadline_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceSchedule
constructor
A new instance of MaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceSchedule
Returns a new instance of MaintenanceSchedule.
3237 3238 3239 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reschedule ⇒ Boolean Also known as: can_reschedule?
If the scheduled maintenance can be rescheduled, default is true.
Corresponds to the JSON property canReschedule
3216 3217 3218 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3216 def can_reschedule @can_reschedule end |
#end_time ⇒ String
Output only. The end time of any upcoming scheduled maintenance for this
instance.
Corresponds to the JSON property endTime
3223 3224 3225 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3223 def end_time @end_time end |
#schedule_deadline_time ⇒ String
Output only. The deadline that the maintenance schedule start time can not go
beyond, including reschedule.
Corresponds to the JSON property scheduleDeadlineTime
3229 3230 3231 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3229 def schedule_deadline_time @schedule_deadline_time end |
#start_time ⇒ String
Output only. The start time of any upcoming scheduled maintenance for this
instance.
Corresponds to the JSON property startTime
3235 3236 3237 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3235 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3242 3243 3244 3245 3246 3247 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3242 def update!(**args) @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule) @end_time = args[:end_time] if args.key?(:end_time) @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time) @start_time = args[:start_time] if args.key?(:start_time) end |