Class: Google::Apis::RedisV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Pre-defined metadata fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



3215
3216
3217
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3179
3180
3181
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3179

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3184
3185
3186
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3184

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


3189
3190
3191
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3189

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


3197
3198
3199
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3197

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3203
3204
3205
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3203

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3208

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


3213
3214
3215
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3213

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3220
3221
3222
3223
3224
3225
3226
3227
3228
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3220

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end