Class: Google::Apis::RedisV1beta1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Pre-defined metadata fields.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
3215 3216 3217 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3179 3180 3181 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3179 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3184 3185 3186 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3184 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3189 3190 3191 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3189 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
3197 3198 3199 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3197 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
3203 3204 3205 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3203 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3208 3209 3210 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3208 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3213 3214 3215 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3213 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3220 3221 3222 3223 3224 3225 3226 3227 3228 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3220 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |