Class: Google::Apis::RedisV1beta1::PscAutoConnection
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::PscAutoConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#connection_type ⇒ String
Output only.
-
#forwarding_rule ⇒ String
Output only.
-
#network ⇒ String
Required.
-
#project_id ⇒ String
Required.
-
#psc_connection_id ⇒ String
Output only.
-
#psc_connection_status ⇒ String
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnection
constructor
A new instance of PscAutoConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnection
Returns a new instance of PscAutoConnection.
3959 3960 3961 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. The IP allocated on the consumer network for the PSC forwarding
rule.
Corresponds to the JSON property address
3915 3916 3917 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3915 def address @address end |
#connection_type ⇒ String
Output only. Type of the PSC connection.
Corresponds to the JSON property connectionType
3920 3921 3922 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3920 def connection_type @connection_type end |
#forwarding_rule ⇒ String
Output only. The URI of the consumer side forwarding rule. Example: projects/
projectNumOrId/regions/us-east1/forwardingRules/resourceId.
Corresponds to the JSON property forwardingRule
3926 3927 3928 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3926 def forwarding_rule @forwarding_rule end |
#network ⇒ String
Required. The consumer network where the IP address resides, in the form of
projects/project_id/global/networks/network_id.
Corresponds to the JSON property network
3932 3933 3934 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3932 def network @network end |
#project_id ⇒ String
Required. The consumer project_id where the forwarding rule is created from.
Corresponds to the JSON property projectId
3937 3938 3939 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3937 def project_id @project_id end |
#psc_connection_id ⇒ String
Output only. The PSC connection id of the forwarding rule connected to the
service attachment.
Corresponds to the JSON property pscConnectionId
3943 3944 3945 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3943 def psc_connection_id @psc_connection_id end |
#psc_connection_status ⇒ String
Output only. The status of the PSC connection. Please note that this value is
updated periodically. Please use Private Service Connect APIs for the latest
status.
Corresponds to the JSON property pscConnectionStatus
3950 3951 3952 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3950 def psc_connection_status @psc_connection_status end |
#service_attachment ⇒ String
Output only. The service attachment which is the target of the PSC connection,
in the form of projects/project-id/regions/region/serviceAttachments/
service-attachment-id.
Corresponds to the JSON property serviceAttachment
3957 3958 3959 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3957 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3964 def update!(**args) @address = args[:address] if args.key?(:address) @connection_type = args[:connection_type] if args.key?(:connection_type) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @network = args[:network] if args.key?(:network) @project_id = args[:project_id] if args.key?(:project_id) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |