Class: Google::Apis::RedisV1beta1::PscAutoConnection
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::PscAutoConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#connection_type ⇒ String
Output only.
-
#forwarding_rule ⇒ String
Output only.
-
#network ⇒ String
Required.
-
#project_id ⇒ String
Required.
-
#psc_connection_id ⇒ String
Output only.
-
#psc_connection_status ⇒ String
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnection
constructor
A new instance of PscAutoConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnection
Returns a new instance of PscAutoConnection.
3748 3749 3750 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. The IP allocated on the consumer network for the PSC forwarding
rule.
Corresponds to the JSON property address
3704 3705 3706 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3704 def address @address end |
#connection_type ⇒ String
Output only. Type of the PSC connection.
Corresponds to the JSON property connectionType
3709 3710 3711 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3709 def connection_type @connection_type end |
#forwarding_rule ⇒ String
Output only. The URI of the consumer side forwarding rule. Example: projects/
projectNumOrId/regions/us-east1/forwardingRules/resourceId.
Corresponds to the JSON property forwardingRule
3715 3716 3717 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3715 def forwarding_rule @forwarding_rule end |
#network ⇒ String
Required. The consumer network where the IP address resides, in the form of
projects/project_id/global/networks/network_id.
Corresponds to the JSON property network
3721 3722 3723 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3721 def network @network end |
#project_id ⇒ String
Required. The consumer project_id where the forwarding rule is created from.
Corresponds to the JSON property projectId
3726 3727 3728 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3726 def project_id @project_id end |
#psc_connection_id ⇒ String
Output only. The PSC connection id of the forwarding rule connected to the
service attachment.
Corresponds to the JSON property pscConnectionId
3732 3733 3734 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3732 def psc_connection_id @psc_connection_id end |
#psc_connection_status ⇒ String
Output only. The status of the PSC connection. Please note that this value is
updated periodically. Please use Private Service Connect APIs for the latest
status.
Corresponds to the JSON property pscConnectionStatus
3739 3740 3741 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3739 def psc_connection_status @psc_connection_status end |
#service_attachment ⇒ String
Output only. The service attachment which is the target of the PSC connection,
in the form of projects/project-id/regions/region/serviceAttachments/
service-attachment-id.
Corresponds to the JSON property serviceAttachment
3746 3747 3748 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3746 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3753 def update!(**args) @address = args[:address] if args.key?(:address) @connection_type = args[:connection_type] if args.key?(:connection_type) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @network = args[:network] if args.key?(:network) @project_id = args[:project_id] if args.key?(:project_id) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |