Class: Google::Apis::RedisV1beta1::PscConnection
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::PscConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Details of consumer resources in a PSC connection.
Instance Attribute Summary collapse
-
#address ⇒ String
Required.
-
#connection_type ⇒ String
Output only.
-
#forwarding_rule ⇒ String
Required.
-
#network ⇒ String
Required.
-
#port ⇒ Fixnum
Output only.
-
#project_id ⇒ String
Optional.
-
#psc_connection_id ⇒ String
Required.
-
#psc_connection_status ⇒ String
Output only.
-
#service_attachment ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscConnection
constructor
A new instance of PscConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscConnection
Returns a new instance of PscConnection.
3845 3846 3847 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Required. The IP allocated on the consumer network for the PSC forwarding rule.
Corresponds to the JSON property address
3794 3795 3796 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3794 def address @address end |
#connection_type ⇒ String
Output only. Type of the PSC connection.
Corresponds to the JSON property connectionType
3799 3800 3801 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3799 def connection_type @connection_type end |
#forwarding_rule ⇒ String
Required. The URI of the consumer side forwarding rule. Example: projects/
projectNumOrId/regions/us-east1/forwardingRules/resourceId.
Corresponds to the JSON property forwardingRule
3805 3806 3807 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3805 def forwarding_rule @forwarding_rule end |
#network ⇒ String
Required. The consumer network where the IP address resides, in the form of
projects/project_id/global/networks/network_id.
Corresponds to the JSON property network
3811 3812 3813 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3811 def network @network end |
#port ⇒ Fixnum
Output only. port will only be set for Primary/Reader or Discovery endpoint.
Corresponds to the JSON property port
3816 3817 3818 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3816 def port @port end |
#project_id ⇒ String
Optional. Project ID of the consumer project where the forwarding rule is
created in.
Corresponds to the JSON property projectId
3822 3823 3824 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3822 def project_id @project_id end |
#psc_connection_id ⇒ String
Required. The PSC connection id of the forwarding rule connected to the
service attachment.
Corresponds to the JSON property pscConnectionId
3828 3829 3830 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3828 def psc_connection_id @psc_connection_id end |
#psc_connection_status ⇒ String
Output only. The status of the PSC connection. Please note that this value is
updated periodically. To get the latest status of a PSC connection, follow
https://cloud.google.com/vpc/docs/configure-private-service-connect-services#
endpoint-details.
Corresponds to the JSON property pscConnectionStatus
3836 3837 3838 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3836 def psc_connection_status @psc_connection_status end |
#service_attachment ⇒ String
Required. The service attachment which is the target of the PSC connection, in
the form of projects/project-id/regions/region/serviceAttachments/service-
attachment-id.
Corresponds to the JSON property serviceAttachment
3843 3844 3845 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3843 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3850 def update!(**args) @address = args[:address] if args.key?(:address) @connection_type = args[:connection_type] if args.key?(:connection_type) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @network = args[:network] if args.key?(:network) @port = args[:port] if args.key?(:port) @project_id = args[:project_id] if args.key?(:project_id) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |