Class: Google::Apis::RedisV1beta1::RemoteCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Details of the remote cluster associated with this cluster in a cross cluster replication setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteCluster

Returns a new instance of RemoteCluster.



3997
3998
3999
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Output only. The full resource path of the remote cluster in the format: projects//locations//clusters/ Corresponds to the JSON property cluster

Returns:

  • (String)


3990
3991
3992
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3990

def cluster
  @cluster
end

#uidString

Output only. The unique identifier of the remote cluster. Corresponds to the JSON property uid

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3995

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4002
4003
4004
4005
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4002

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @uid = args[:uid] if args.key?(:uid)
end