Class: Google::Apis::RedisV1beta1::RemoteCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Details of the remote cluster associated with this cluster in a cross cluster replication setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteCluster

Returns a new instance of RemoteCluster.



3598
3599
3600
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Output only. The full resource path of the remote cluster in the format: projects//locations//clusters/ Corresponds to the JSON property cluster

Returns:

  • (String)


3591
3592
3593
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3591

def cluster
  @cluster
end

#uidString

Output only. The unique identifier of the remote cluster. Corresponds to the JSON property uid

Returns:

  • (String)


3596
3597
3598
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3596

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3603
3604
3605
3606
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3603

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @uid = args[:uid] if args.key?(:uid)
end