Class: Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Deny maintenance period for the database resource. It specifies the time range during which the maintenance cannot start. This is configured by the customer.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
constructor
A new instance of ResourceMaintenanceDenySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
Returns a new instance of ResourceMaintenanceDenySchedule.
3701 3702 3703 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
3680 3681 3682 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3680 def end_date @end_date end |
#start_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
3692 3693 3694 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3692 def start_date @start_date end |
#time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
3699 3700 3701 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3699 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3706 3707 3708 3709 3710 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3706 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |