Class: Google::Apis::RedisV1beta1::ResourceMaintenanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

MaintenanceInfo to capture the maintenance details of database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceMaintenanceInfo

Returns a new instance of ResourceMaintenanceInfo.



4195
4196
4197
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_version_release_dateGoogle::Apis::RedisV1beta1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property currentVersionReleaseDate



4151
4152
4153
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4151

def current_version_release_date
  @current_version_release_date
end

#deny_maintenance_schedulesArray<Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule>

Optional. List of Deny maintenance period for the database resource. Corresponds to the JSON property denyMaintenanceSchedules



4156
4157
4158
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4156

def deny_maintenance_schedules
  @deny_maintenance_schedules
end

#is_instance_stoppedBoolean Also known as: is_instance_stopped?

Optional. Whether the instance is in stopped state. This information is temporarily being captured in maintenanceInfo, till STOPPED state is supported by DB Center. Corresponds to the JSON property isInstanceStopped

Returns:

  • (Boolean)


4163
4164
4165
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4163

def is_instance_stopped
  @is_instance_stopped
end

#maintenance_scheduleGoogle::Apis::RedisV1beta1::ResourceMaintenanceSchedule

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer. Corresponds to the JSON property maintenanceSchedule



4171
4172
4173
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4171

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_stateString

Output only. Current state of maintenance on the database resource. Corresponds to the JSON property maintenanceState

Returns:

  • (String)


4176
4177
4178
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4176

def maintenance_state
  @maintenance_state
end

#maintenance_versionString

Optional. Current Maintenance version of the database resource. Example: " MYSQL_8_0_41.R20250531.01_15" Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


4182
4183
4184
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4182

def maintenance_version
  @maintenance_version
end

#next_available_maintenance_versionsArray<String>

Optional. List of next available maintenance versions. Corresponds to the JSON property nextAvailableMaintenanceVersions

Returns:

  • (Array<String>)


4187
4188
4189
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4187

def next_available_maintenance_versions
  @next_available_maintenance_versions
end

#upcoming_maintenanceGoogle::Apis::RedisV1beta1::UpcomingMaintenance

Upcoming maintenance for the database resource. This is generated by SLM once the upcoming maintenance schedule is published. Corresponds to the JSON property upcomingMaintenance



4193
4194
4195
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4193

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4200

def update!(**args)
  @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date)
  @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules)
  @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @next_available_maintenance_versions = args[:next_available_maintenance_versions] if args.key?(:next_available_maintenance_versions)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end