Class: Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
MaintenanceInfo to capture the maintenance details of database resource.
Instance Attribute Summary collapse
-
#current_version_release_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#deny_maintenance_schedules ⇒ Array<Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule>
Optional.
-
#is_instance_stopped ⇒ Boolean
(also: #is_instance_stopped?)
Optional.
-
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceSchedule
Maintenance window for the database resource.
-
#maintenance_state ⇒ String
Output only.
-
#maintenance_version ⇒ String
Optional.
-
#upcoming_maintenance ⇒ Google::Apis::RedisV1beta1::UpcomingMaintenance
Upcoming maintenance for the database resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceInfo
constructor
A new instance of ResourceMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceInfo
Returns a new instance of ResourceMaintenanceInfo.
4144 4145 4146 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_version_release_date ⇒ Google::Apis::RedisV1beta1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property currentVersionReleaseDate
4105 4106 4107 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4105 def current_version_release_date @current_version_release_date end |
#deny_maintenance_schedules ⇒ Array<Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule>
Optional. List of Deny maintenance period for the database resource.
Corresponds to the JSON property denyMaintenanceSchedules
4110 4111 4112 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4110 def deny_maintenance_schedules @deny_maintenance_schedules end |
#is_instance_stopped ⇒ Boolean Also known as: is_instance_stopped?
Optional. Whether the instance is in stopped state. This information is
temporarily being captured in maintenanceInfo, till STOPPED state is supported
by DB Center.
Corresponds to the JSON property isInstanceStopped
4117 4118 4119 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4117 def is_instance_stopped @is_instance_stopped end |
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceSchedule
Maintenance window for the database resource. It specifies preferred time and
day of the week and phase in some cases, when the maintenance can start. This
is configured by the customer.
Corresponds to the JSON property maintenanceSchedule
4125 4126 4127 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4125 def maintenance_schedule @maintenance_schedule end |
#maintenance_state ⇒ String
Output only. Current state of maintenance on the database resource.
Corresponds to the JSON property maintenanceState
4130 4131 4132 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4130 def maintenance_state @maintenance_state end |
#maintenance_version ⇒ String
Optional. Current Maintenance version of the database resource. Example: "
MYSQL_8_0_41.R20250531.01_15"
Corresponds to the JSON property maintenanceVersion
4136 4137 4138 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4136 def maintenance_version @maintenance_version end |
#upcoming_maintenance ⇒ Google::Apis::RedisV1beta1::UpcomingMaintenance
Upcoming maintenance for the database resource. This is generated by SLM once
the upcoming maintenance schedule is published.
Corresponds to the JSON property upcomingMaintenance
4142 4143 4144 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4142 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4149 4150 4151 4152 4153 4154 4155 4156 4157 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4149 def update!(**args) @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date) @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules) @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |