Class: Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::ResourceMaintenanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
MaintenanceInfo to capture the maintenance details of database resource.
Instance Attribute Summary collapse
-
#deny_maintenance_schedules ⇒ Array<Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule>
Optional.
-
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceSchedule
Maintenance window for the database resource.
-
#maintenance_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceInfo
constructor
A new instance of ResourceMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceInfo
Returns a new instance of ResourceMaintenanceInfo.
3735 3736 3737 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deny_maintenance_schedules ⇒ Array<Google::Apis::RedisV1beta1::ResourceMaintenanceDenySchedule>
Optional. List of Deny maintenance period for the database resource.
Corresponds to the JSON property denyMaintenanceSchedules
3720 3721 3722 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3720 def deny_maintenance_schedules @deny_maintenance_schedules end |
#maintenance_schedule ⇒ Google::Apis::RedisV1beta1::ResourceMaintenanceSchedule
Maintenance window for the database resource. It specifies preferred time and
day of the week and phase in some cases, when the maintenance can start. This
is configured by the customer.
Corresponds to the JSON property maintenanceSchedule
3727 3728 3729 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3727 def maintenance_schedule @maintenance_schedule end |
#maintenance_version ⇒ String
Optional. Current Maintenance version of the database resource. Example: "
MYSQL_8_0_41.R20250531.01_15"
Corresponds to the JSON property maintenanceVersion
3733 3734 3735 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3733 def maintenance_version @maintenance_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3740 3741 3742 3743 3744 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 3740 def update!(**args) @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) end |