Class: Google::Apis::RedisV1beta1::ResourceMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb

Overview

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceMaintenanceSchedule

Returns a new instance of ResourceMaintenanceSchedule.



4238
4239
4240
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Corresponds to the JSON property day

Returns:

  • (String)


4220
4221
4222
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4220

def day
  @day
end

#phaseString

Optional. Phase of the maintenance window. This is to capture order of maintenance. For example, for Cloud SQL resources, this can be used to capture if the maintenance window is in Week1, Week2, Week5, etc. Non production resources are usually part of early phase. For more details, refer to Cloud SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance Corresponds to the JSON property phase

Returns:

  • (String)


4229
4230
4231
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4229

def phase
  @phase
end

#timeGoogle::Apis::RedisV1beta1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



4236
4237
4238
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4236

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4243
4244
4245
4246
4247
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4243

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @phase = args[:phase] if args.key?(:phase)
  @time = args[:time] if args.key?(:time)
end