Class: Google::Apis::RedisV1beta1::TokenAuthUser
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::TokenAuthUser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Represents a token based auth user for the cluster.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TokenAuthUser
constructor
A new instance of TokenAuthUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TokenAuthUser
Returns a new instance of TokenAuthUser.
4482 4483 4484 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The resource name of the token based auth user. Format: projects/
project/locations/location/clusters/cluster/tokenAuthUsers/
token_auth_user
Corresponds to the JSON property name
4475 4476 4477 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4475 def name @name end |
#state ⇒ String
Output only. The state of the token based auth user.
Corresponds to the JSON property state
4480 4481 4482 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4480 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4487 4488 4489 4490 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4487 def update!(**args) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |