Class: Google::Apis::RedisV1beta1::WeeklyMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1beta1::WeeklyMaintenanceWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1beta1/classes.rb,
lib/google/apis/redis_v1beta1/representations.rb,
lib/google/apis/redis_v1beta1/representations.rb
Overview
Time window in which disruptive maintenance updates occur. Non-disruptive updates can occur inside or outside this window.
Instance Attribute Summary collapse
-
#day ⇒ String
Required.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WeeklyMaintenanceWindow
constructor
A new instance of WeeklyMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WeeklyMaintenanceWindow
Returns a new instance of WeeklyMaintenanceWindow.
4309 4310 4311 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Required. The day of week that maintenance updates occur.
Corresponds to the JSON property day
4294 4295 4296 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4294 def day @day end |
#duration ⇒ String
Output only. Duration of the maintenance window. The current window is fixed
at 1 hour.
Corresponds to the JSON property duration
4300 4301 4302 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4300 def duration @duration end |
#start_time ⇒ Google::Apis::RedisV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
4307 4308 4309 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4307 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4314 4315 4316 4317 4318 |
# File 'lib/google/apis/redis_v1beta1/classes.rb', line 4314 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |